<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package itcode
 * @since 1.0
 * @version 1.0
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div class="card comments-area" id="comments">

	<?php // You can start editing here -- including this comment! ?>

	<?php if ( have_comments() ) : ?>
        <div class="card-block">
            <h2 class="card-title comments-title">
                <?php
                $comments_number = get_comments_number();
                if ( 1 === $comments_number ) {
                    printf(
                    /* translators: %s: post title */
                        esc_html_x( 'One thought on &ldquo;%s&rdquo;', 'comments title', 'itcode' ),
                        '<span>' . get_the_title() . '</span>'
                    );
                } else {
                    printf( // WPCS: XSS OK.
                    /* translators: 1: number of comments, 2: post title */
                        esc_html( _nx(
                            '%1$s thought on &ldquo;%2$s&rdquo;',
                            '%1$s thoughts on &ldquo;%2$s&rdquo;',
                            $comments_number,
                            'comments title',
                            'itcode'
                        ) ),
                        number_format_i18n( $comments_number ),
                        '<span>' . get_the_title() . '</span>'
                    );
                }
                ?>
            </h2><!-- .comments-title -->
        </div>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through. ?>
            <div class="card-block">
                <nav class="comment-navigation d-flex justify-content-between my-2" id="comment-nav-above">
                    <?php if ( get_previous_comments_link() ) { ?>
                        <div class="nav-previous">
                            <?php previous_comments_link( __( '&larr; Older Comments', 'itcode' ) ); ?>
                        </div>
                    <?php } ?>

                    <h1 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'itcode' ); ?></h1>

                    <?php if ( get_next_comments_link() ) { ?>
                        <div class="nav-next">
                            <?php next_comments_link( __( 'Newer Comments &rarr;', 'itcode' ) ); ?>
                        </div>
                    <?php } ?>
                </nav><!-- #comment-nav-above -->
            </div>

		<?php endif; // check for comment navigation. ?>

        <div class="card-block">

            <ul class="list-group list-group-flush comment-list">
                <?php wp_list_comments( array(
                    'style'       => 'li',
                    'callback'    => 'itcode_render_comments',
                    'avatar_size' => 50,
                    'short_ping'  => true,
                ) ); ?>
            </ul>
            <!-- .comment-list -->
        </div>

        <div class="card-block">
            <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through. ?>
                <nav class="comment-navigation my-2" id="comment-nav-below">
                    <div class="d-flex justify-content-between">
                        <?php if ( get_previous_comments_link() ) { ?>
                            <div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments',
                                    'itcode' ) ); ?></div>
                        <?php } ?>
                        <h1 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'itcode' ); ?></h1>
                        <?php if ( get_next_comments_link() ) { ?>
                            <div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;',
                                    'itcode' ) ); ?></div>
                        <?php } ?>
                    </div>
                </nav><!-- #comment-nav-below -->
            <?php endif; // check for comment navigation. ?>
        </div>

	<?php endif; // endif have_comments(). ?>

	<?php
	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
		?>
        <div class="card-block">
            <div class="alert alert-warning no-comments d-flex justify-content-center" role="alert">
                <?php esc_html_e( 'Comments are closed.', 'itcode' ); ?>
            </div>
        </div>
    <?php endif; ?>
    <div class="card-block">
        <?php itcode_comment_form(); // Render comments form. ?>
    </div>

</div><!-- #comments -->
