<?php
/**
 * The front page template file
 *
 * If the user has selected a static page for their homepage, this is what will
 * appear.
 * Learn more: https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Twenty_Seventeen
 * @since 1.0
 * @version 1.0
 */

get_header();



$layout_style = itcode_get_post_meta( $post->ID, 'itcode_page_layout', true );
if ( ( $layout_style === '' ) || ( $layout_style == '-1' ) ) {
    $layout_style = get_theme_mod('itcode_container_type');  // todo  fix full...
}

$sidebar = itcode_get_post_meta( $post->ID, 'itcode_page_sidebar', true );
if ( ( $sidebar === '' ) || ( $sidebar == '-1' ) ) {
    $sidebar = '';//get_theme_mod('page_sidebar_position');
}

$left_sidebar = itcode_get_post_meta( $post->ID, 'itcode_page_left_sidebar', true );
if ( ( $left_sidebar === '' ) || ( $left_sidebar == '-1' ) ) {
    $left_sidebar = get_theme_mod('page_left_sidebar' , 'sidebar-1');

}

$right_sidebar = itcode_get_post_meta( $post->ID, 'itcode_page_right_sidebar', true );
if ( ( $right_sidebar === '' ) || ( $right_sidebar == '-1' ) ) {
    $right_sidebar = get_theme_mod('page_right_sidebar' , 'sidebar-2');
}

$sidebar_width = itcode_get_post_meta( $post->ID, 'itcode_sidebar_width', true );
if ( ( $sidebar_width === '' ) || ( $sidebar_width == '-1' ) ) {
    $sidebar_width = get_theme_mod('page_sidebar_width', 'small');
}

$page_comment = get_itcode_options('page_comment');
//var_dump(get_itcode_options('page_comment'));

// Calculate sidebar column & content column
$sidebar_col = 'col-md-3';
if ( $sidebar_width == 'large' ) {
    $sidebar_col = 'col-md-4';
}

$content_col_number = 12;
if ( is_active_sidebar( $left_sidebar ) && ( ( $sidebar == 'both' ) || ( $sidebar == 'left' ) ) ) {
    if ( $sidebar_width == 'large' ) {
        $content_col_number -= 4;
    } else {
        $content_col_number -= 3;
    }
}
if ( is_active_sidebar( $right_sidebar ) && ( ( $sidebar == 'both' ) || ( $sidebar == 'right' ) ) ) {
    if ( $sidebar_width == 'large' ) {
        $content_col_number -= 4;
    } else {
        $content_col_number -= 3;
    }
}

$content_col = 'col-md-' . $content_col_number;
if ( ( $content_col_number == 12 ) && ( $layout_style == 'full' ) ) {
    $content_col = '';
}

$main_class = array( 'site-main' );

if ( $content_col_number < 12 ) {
    $main_class[] = 'has-sidebar';
}
?>

<div id="primary" class="content-area">
    <main class="<?php echo join( ' ', $main_class ) ?>" role="main">
        <?php if ( $layout_style != 'full' ): ?>
        <div class="<?php echo esc_attr( $layout_style ) ?> clearfix">
            <?php endif; ?>
            <?php if ( ( $content_col_number != 12 ) || ( $layout_style != 'full' ) ): ?>
            <div class="row clearfix">
                <?php endif; ?>
                <?php if ( is_active_sidebar( $left_sidebar ) && ( ( $sidebar == 'left' ) || ( $sidebar == 'both' ) ) ): ?>
                    <div class="sidebar left-sidebar <?php echo esc_attr( $sidebar_col ) ?>">
                        <?php dynamic_sidebar( $left_sidebar ); ?>
                    </div> <!-- end left-sidebar -->
                <?php endif; ?>
                <div class="site-content-page-inner <?php echo esc_attr( $content_col ) ?>">



                    <div class="page-content">
                        <?php // Show the selected frontpage content.
                        if ( have_posts() ) :
                            while ( have_posts() ) : the_post();
                                get_template_part( 'template-parts/page/content', 'front-page' );
                            endwhile;
                        else : // I'm not sure it's possible to have no posts when this page is shown, but WTH.
                            get_template_part( 'template-parts/post/content', 'none' );
                        endif; ?>

                        <?php
                        // Get each of our panels and show the post data.
                        if ( 0 !== itcode_panel_count() || is_customize_preview() ) : // If we have pages to show.

                            /**
                             * Filter number of front page sections in Twenty Seventeen.
                             *
                             * @since Twenty Seventeen 1.0
                             *
                             * @param $num_sections integer
                             */
                            $num_sections = apply_filters( 'itcode_front_page_sections', 4 );
                            global $itcodecounter;

                            // Create a setting and control for each of the sections available in the theme.
                            for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
                                $itcodecounter = $i;
                                itcode_front_page_section( null, $i );
                            }

                        endif; // The if ( 0 !== itcode_panel_count() ) ends here. ?>
                    </div> <!-- end page-content -->




                </div> <!-- end site-content-page-inner -->
                <?php if ( is_active_sidebar( $right_sidebar ) && ( ( $sidebar == 'right' ) || ( $sidebar == 'both' ) ) ): ?>

                    <div class="sidebar right-sidebar <?php echo esc_attr( $sidebar_col ) ?>">
                        <?php dynamic_sidebar( $right_sidebar ); ?>
                    </div> <!-- end right-sidebar -->
                <?php endif; ?>
                <?php if ( ( $content_col_number != 12 ) || ( $layout_style != 'full' ) ): ?>
            </div>
        <?php endif; ?>
            <?php if ( $layout_style != 'full' ): ?>
        </div>
    <?php endif; ?>
    </main><!-- #main -->
</div><!-- #primary -->

<?php get_footer();
