<?php
/**
 * ItCode Theme functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
* @package itcode
 * @since 1.0
 */

/**
 * ItCode Theme only works in WordPress 4.7 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
	return;
}

/**
 * Theme setup and custom theme supports.
 */
require get_template_directory() . '/inc/setup.php';




/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function itcode_content_width() {

	$content_width = $GLOBALS['content_width'];

	// Get layout.
	$page_layout = get_theme_mod( 'page_layout' );

	// Check if layout is one column.
	if ( 'one-column' === $page_layout ) {
		if ( itcode_is_frontpage() ) {
			$content_width = 644;
		} elseif ( is_page() ) {
			$content_width = 740;
		}
	}

	// Check if is single post and there is no sidebar.
	if ( is_single() && ! is_active_sidebar( 'sidebar-1' ) ) {
		$content_width = 740;
	}

	/**
	 * Filter Twenty Seventeen content width of the theme.
	 *
	 * @since Twenty Seventeen 1.0
	 *
	 * @param $content_width integer
	 */
	$GLOBALS['content_width'] = apply_filters( 'itcode_content_width', $content_width );
}
add_action( 'template_redirect', 'itcode_content_width', 0 );




if ( !function_exists( 'itcode_theme_activation' ) ) {
    function itcode_theme_activation() {
        // set frontpage to display_posts
        update_option( 'show_on_front', 'posts' );

        // flush rewrite rules
        flush_rewrite_rules();

        do_action( 'itcode_theme_activation' );

        if ( class_exists( 'TGM_Plugin_Activation' ) ) {
            $tgmpa                       = TGM_Plugin_Activation::$instance;
            $is_redirect_require_install = false;
            foreach ( $tgmpa->plugins as $p ) {
                $path = ABSPATH . 'wp-content/plugins/' . $p['slug'];
                if ( !is_dir( $path ) ) {
                    $is_redirect_require_install = true;
                    break;
                }
            }
            if ( $is_redirect_require_install ) {
                header( 'Location: ' . admin_url() . 'themes.php?page=install-required-plugins' ); // todo fix work 
            }
        }
    }

    add_action( 'after_switch_theme', 'itcode_theme_activation' );
}

/**
 * Register custom fonts.
 */
function itcode_fonts_url() {
	$fonts_url = '';

	/**
	 * Translators: If there are characters in your language that are not
	 * supported by Libre Franklin, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$libre_franklin = _x( 'on', 'Libre Franklin font: on or off', 'itcode' );

	if ( 'off' !== $libre_franklin ) {
		$font_families = array();

		$font_families[] = 'Libre Franklin:300,300i,400,400i,600,600i,800,800i';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}

/**
 * Add preconnect for Google Fonts.
 *
 * @since Twenty Seventeen 1.0
 *
 * @param array  $urls           URLs to print for resource hints.
 * @param string $relation_type  The relation type the URLs are printed.
 * @return array $urls           URLs to print for resource hints.
 */
function itcode_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'itcode-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}

	return $urls;
}
add_filter( 'wp_resource_hints', 'itcode_resource_hints', 10, 2 );






if ( !function_exists( 'itcode_include_library' ) ) {
	function itcode_include_library() {



        /**
         * Register widget area.
         *
         * @link http://codex.wordpress.org/Function_Reference/register_sidebar
         */
        require get_template_directory() . '/inc/widgets.php';

        /**
         * Load functions to secure your WP install.
         */
        require get_template_directory() . '/inc/security.php';

        /**
         * Enqueue scripts and styles.
         */
        require get_template_directory() . '/inc/enqueue.php';

        /**
         * Custom template tags for this theme.
         */
        require get_template_directory() . '/inc/template-tags.php';

        /**
         * Custom template tags for this theme.
         */
        //require get_template_directory() . '/inc/pagination.php';

        /**
         * Custom functions that act independently of the theme templates.
         */
//require get_template_directory() . '/inc/extras.php';

        /**
         * Kirki plugin
         */
        require get_template_directory() . '/inc/kirki/kirki.php';

        /**
         * Customizer additions.
         */
        require get_template_directory() . '/inc/customizer/customizer.php';


        require get_template_directory() . '/inc/custom-comments.php';

        /**
         * Load Jetpack compatibility file.
         */
        require get_template_directory() . '/inc/jetpack.php';

        /**
         * Load custom WordPress nav walker.
         */
        require get_template_directory() . '/inc/bootstrap-wp-navwalker.php';

        /**
         * Load WooCommerce functions.
         */
        //require get_template_directory() . '/inc/woocommerce.php';

        /**
         * Load Editor functions.
         */
        require get_template_directory() . '/inc/editor.php';


        /**
         * Implement the Custom Header feature.
         */
        require get_parent_theme_file_path( '/inc/custom-header.php' );

        /**
         * Custom template tags for this theme.
         */
        require get_parent_theme_file_path( '/inc/template-tags.php' );

        /**
         * Additional features to allow styling of the templates.
         */
        require get_parent_theme_file_path( '/inc/template-functions.php' );


        /**
         * Load CMB2 functions.
         */
        //require get_template_directory() . '/inc/cmb2/example-functions.php';
        /*
        if ( file_exists( dirname( __FILE__ ) . '/inc/cmb2/init.php' ) ) {
            require_once dirname( __FILE__ ) . '/inc/cmb2/init.php';
        } elseif ( file_exists( dirname( __FILE__ ) . '/inc/CMB2/init.php' ) ) {
            require_once dirname( __FILE__ ) . '/inc/CMB2/init.php';
        } // todo заміна метабоксу але погано працює

        require get_template_directory() . '/inc/cmb2/cmb_init.php';*/


        require  get_template_directory() . '/inc/meta-box/meta-box.php';

        require  get_template_directory() . '/inc/meta-box/itcode-meta-box.php';

        require  get_template_directory() . '/inc/helpers/get-the-image.php';

        require  get_template_directory() . '/inc/plugins/plugin-activator/tgm-init.php';

        require  get_template_directory() . '/inc/demo-content/ocdi-import.php';

        require get_template_directory() . '/inc/admin/core/resize.php' ;

        require get_template_directory() . '/inc/admin/core/action.php' ;

        require get_template_directory() . '/inc/admin/core/wp-core.php' ;

        require get_template_directory() . '/inc/admin/core/filter.php' ;

        //require get_template_directory() . '/inc/helpers/breadcrumb.php' ;

        require get_template_directory() . '/inc/admin/core/woocommerce.php' ;

        require get_template_directory()  . '/inc/admin-enqueue.php' ;

        require get_template_directory()  . '/inc/theme-functions.php' ;

        require get_template_directory()  . '/inc/theme-action.php' ;

        require get_template_directory()  . '/inc/theme-filter.php' ;

        require get_template_directory() . '/inc/tax-meta-class/Tax-meta-class.php' ;

        require get_template_directory()  . '/inc/tax-meta.php' ;

        require get_template_directory() . '/inc/breadcrumb.php' ;


        /**
         * SVG icons functions and filters.
         */
        require get_parent_theme_file_path( '/inc/icon-functions.php' );


    }

	itcode_include_library();
}

if ( !function_exists( 'itcode_style_schemes_output' ) ) {
	function itcode_style_schemes_output( $custom_style = '' ) {
		ob_start();
		echo( '<style>' . $custom_style . '</style>' );
		$content = ob_get_clean();

		return $content;
	}

	add_action( 'wp_head', 'itcode_style_schemes_output', 10000000 );
}

if ( !function_exists( 'itcode_hex2rgba' ) ) {
	function itcode_hex2rgba( $hex, $alpha = '' ) {
		$hex = str_replace( "#", "", $hex );
		if ( strlen( $hex ) == 3 ) {
			$r = hexdec( substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) );
			$g = hexdec( substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) );
			$b = hexdec( substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) );
		} else {
			$r = hexdec( substr( $hex, 0, 2 ) );
			$g = hexdec( substr( $hex, 2, 2 ) );
			$b = hexdec( substr( $hex, 4, 2 ) );
		}
		$rgb = $r . ',' . $g . ',' . $b;

		if ( '' == $alpha ) {
			return 'rgb(' . $rgb . ')';
		} else {
			$alpha = floatval( $alpha );

			return 'rgba(' . $rgb . ',' . $alpha . ')';
		}
	}
}
if ( !function_exists( 'woocommerce_clear_cart_url' ) ) {
	// check for empty-cart get param to clear the cart
	add_action( 'init', 'woocommerce_clear_cart_url' );
	function woocommerce_clear_cart_url() {
		global $woocommerce;
		if ( isset( $_GET['empty-cart'] ) ) {
			$woocommerce->cart->empty_cart();

		}
	}
}

/*================================================
SITE LOADING
================================================== */
/*if ( !function_exists( 'itcode_site_loading' ) ) {
    function itcode_site_loading() {
        get_template_part( 'template-parts/site-loading' );
    }

    add_action( 'itcode_before_page_wrapper', 'itcode_site_loading', 5 );
} // todo disable on js error
*/


/*================================================
SOCIAL META
================================================== */
if ( !function_exists( 'itcode_add_opengraph_doctype' ) ) {
    function itcode_add_opengraph_doctype( $output ) {
        $enable_social_meta = false;
        if ( get_theme_mod('site_enable_social_meta', false ) == true ) {
            $enable_social_meta = get_theme_mod('site_enable_social_meta', false );
        }
        if ( !$enable_social_meta ) {
            return $output;
        }

        return $output . ' xmlns:og="http://opengraphprotocol.org/schema/" xmlns:fb="http://www.facebook.com/2008/fbml"';

    }

    add_filter( 'language_attributes', 'itcode_add_opengraph_doctype' );
}


function get_itcode_options($name = false, $key = false ) {
    /**
     * themp fix get settings var
     */
    global $itcode; // old settings options

    if ($name == false){

        return $itcode;

    }elseif(isset($name)){

        return get_theme_mod($name);

    }elseif($key != false){

        return get_theme_mod( $name, $key );
    }else{
        return get_theme_mod($name);
    }
}




















/*================================================
itcode_loop
================================================== */
if ( !function_exists( 'itcode_loop' ) ) {
    function itcode_loop() {
        global $itcode_loop;
        return $itcode_loop;
    }
}


/*================================================
PAGE HEADING
================================================== */
if ( !function_exists( 'itcode_page_heading' ) ) {
    function itcode_page_heading() {
        get_template_part( 'template-parts/page-heading' );
    }

    add_action( 'itcode_before_page', 'itcode_page_heading', 5 );
}
/*================================================
ARCHIVE HEADING
================================================== */
/*if ( !function_exists( 'itcode_archive_heading' ) ) {
    function itcode_archive_heading() {
        get_template_part( 'template-parts/archive-heading' );
    }

    add_action( 'itcode_before_archive', 'itcode_archive_heading', 5 );
}*/

/*if ( !function_exists( 'itcode_archive_product_heading' ) ) {
    function itcode_archive_product_heading() {
        get_template_part( 'template-parts/archive-product-heading' );
    }

    add_action( 'itcode_before_archive_product', 'itcode_archive_product_heading', 5 );
}*/

/**
 * Toggle Top
 */
/*if ( !function_exists( 'itcode_page_toggle_top' ) ) {
    function itcode_page_toggle_top() {
        get_template_part( 'template-parts/toggle-top-template' );
    }

    add_action( 'itcode_before_page_wrapper_content', 'itcode_page_toggle_top', 10 );
}*/

/**
 * Top Bar
 */
/*if ( !function_exists( 'itcode_page_top_bar' ) ) {
    function itcode_page_top_bar() {
        get_template_part( 'template-parts/top-bar-template' );
    }

    add_action( 'itcode_before_page_wrapper_content', 'itcode_page_top_bar', 15 );
}*/

/**
 * HEADER
 */

/*if ( !function_exists( 'itcode_page_header' ) ) {
    function itcode_page_header() {
        get_template_part( 'template-parts/header-template' );
    }

    add_action( 'itcode_before_page_wrapper_content', 'itcode_page_header', 20 );
}*/


/**
 * GET POST META
 */
if ( !function_exists( 'itcode_get_post_meta' ) ) {
    function itcode_get_post_meta( $id, $key = "", $single = false ) {

        $GLOBALS['itcode_post_meta'] = isset( $GLOBALS['itcode_post_meta'] ) ? $GLOBALS['itcode_post_meta'] : array();
        if ( !isset( $id ) ) {
            return;
        }
        if ( !is_array( $id ) ) {
            if ( !isset( $GLOBALS['itcode_post_meta'][$id] ) ) {
                //$GLOBALS['itcode_post_meta'][ $id ] = array();
                $GLOBALS['itcode_post_meta'][$id] = get_post_meta( $id );
            }
            if ( !empty( $key ) && isset( $GLOBALS['itcode_post_meta'][$id][$key] ) && !empty( $GLOBALS['itcode_post_meta'][$id][$key] ) ) {
                if ( $single ) {
                    return maybe_unserialize( $GLOBALS['itcode_post_meta'][$id][$key][0] );
                } else {
                    return array_map( 'maybe_unserialize', $GLOBALS['itcode_post_meta'][$id][$key] );
                }
            }

            if ( $single ) {
                return '';
            } else {
                return array();
            }

        }

        return get_post_meta( $id, $key, $single );
    }
}

/* GET USER MENU LIST
    ================================================== */
if ( !function_exists( 'itcode_get_menu_list' ) ) {
    function itcode_get_menu_list() {

        if ( !is_admin() ) {
            return array();
        }

        $user_menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );

        $menu_list = array();

        foreach ( $user_menus as $menu ) {
            $menu_list[$menu->term_id] = $menu->name;
        }

        return $menu_list;
    }
}

/**
 * CHECK IS BLOG PAGE
 */
if ( !function_exists( 'itcode_is_blog_page' ) ) {
    function itcode_is_blog_page() {
        global $post;

        //type must be 'post'.
        $post_type = get_post_type( $post );

        return (
            ( is_home() || is_archive() || is_single() )
            && ( $post_type == 'post' )
        ) ? true : false;
    }
}


/**
 * MAINTENANCE MODE
 */
if ( !function_exists( 'itcode_maintenance_mode' ) ) {
    function itcode_maintenance_mode() {

        if ( current_user_can( 'edit_themes' ) || is_user_logged_in() ) { return; }

        $enable_maintenance = get_theme_mod('site_maintenance_mode', 'off' );

        switch ( $enable_maintenance ) {
            case 'on' :
                wp_die( '<p style="text-align:center">' . esc_html__( 'We are currently in maintenance mode, please check back shortly.', 'itcode' ) . '</p>', get_bloginfo( 'name' ) );
                break;
            case 'custom':
                $maintenance_mode_page = get_theme_mod('site_maintenance_mode_custom_page');
                if ( empty( $maintenance_mode_page ) ) {
                    wp_die( '<p style="text-align:center">' . esc_html__( 'We are currently in maintenance mode, please check back shortly.', 'itcode' ) . '</p>', get_bloginfo( 'name' ) );
                } else {
                    $maintenance_mode_page_url = get_permalink( $maintenance_mode_page );
                    $current_page_url          = itcode_current_page_url();
                    if ( $maintenance_mode_page_url != $current_page_url ) {
                        wp_redirect( $maintenance_mode_page_url );
                    }
                }
                break;
        }
    }

    add_action( 'get_header', 'itcode_maintenance_mode' );
}// end function itcode_maintenance_mode

/**
 * GET CURRENT PAGE URL
 */
if ( !function_exists( 'itcode_current_page_url' ) ) {
    function itcode_current_page_url() {
        $pageURL = 'http';
        if ( is_ssl() ) {
            $pageURL .= "s";
        }
        $pageURL .= "://";
        if( isset( $_SERVER["SERVER_NAME"] ) && isset( $_SERVER["REQUEST_URI"] ) ) {
            $pageURL .= $_SERVER["SERVER_NAME"] .  $_SERVER["REQUEST_URI"];
        }
        return $pageURL;
    }
}// end function itcode_current_page_url

/**
 * Paging Load More
 */
if ( !function_exists( 'itcode_paging_load_more' ) ) {
    function itcode_paging_load_more() {
        global $wp_query;
        // Don't print empty markup if there's only one page.
        if ( $wp_query->max_num_pages < 2 ) {
            return;
        }
        $link = get_next_posts_page_link( $wp_query->max_num_pages );
        if ( !empty( $link ) ):
            ?>
            <div class="blog-load-more-wrapper">
                <button data-href="<?php echo esc_url( $link ); ?>" type="button" data-loading-text="<i class='fa fa-refresh fa-spin'></i> <?php echo esc_html__( "Loading...", 'itcode' ); ?>" class="blog-load-more itcode-button style4 size-lg" autocomplete="off">
                    <i class="fa fa-plus"></i> <?php echo esc_html__( "Load More", 'itcode' ); ?>
                </button>
            </div>
            <?php
        endif;
    }
}// end function itcode_paging_load_more

/**
 * Paging Infinite Scroll
 */
if ( !function_exists( 'itcode_paging_infinitescroll' ) ) {
    function itcode_paging_infinitescroll() {
        global $wp_query;
        // Don't print empty markup if there's only one page.
        if ( $wp_query->max_num_pages < 2 ) {
            return;
        }
        $link = get_next_posts_page_link( $wp_query->max_num_pages );
        if ( !empty( $link ) ):
            ?>
            <nav id="infinite_scroll_button">
                <a href="<?php echo esc_url( $link ); ?>"></a>
            </nav>
            <div id="infinite_scroll_loading" class="text-center infinite-scroll-loading"></div>
            <?php
        endif;
    }
}

/**
 * Paging Infinite Nav
 */
if ( !function_exists( 'itcode_paging_nav' ) ) {
    function itcode_paging_nav() {
        global $wp_query, $wp_rewrite;
        // Don't print empty markup if there's only one page.
        if ( $wp_query->max_num_pages < 2 ) {
            return;
        }

        $paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
        $pagenum_link = html_entity_decode( get_pagenum_link() );
        $query_args   = array();
        $url_parts    = explode( '?', $pagenum_link );

        if ( isset( $url_parts[1] ) ) {
            wp_parse_str( $url_parts[1], $query_args );
        }

        $pagenum_link = esc_url( remove_query_arg( array_keys( $query_args ), $pagenum_link ) );
        $pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

        $format = $wp_rewrite->using_index_permalinks() && !strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
        $format .= $wp_rewrite->using_permalinks() ? user_trailingslashit( $wp_rewrite->pagination_base . '/%#%', 'paged' ) : '?paged=%#%';

        // Set up paginated links.
        $page_links = paginate_links( array(
            'base'      => $pagenum_link,
            'format'    => $format,
            'total'     => $wp_query->max_num_pages,
            'current'   => $paged,
            'mid_size'  => 1,
            'add_args'  => array_map( 'urlencode', $query_args ),
            'prev_text' => '<i class="fa fa-angle-double-left"></i>',
            'next_text' => '<i class="fa fa-angle-double-right"></i>',
            'type'      => 'array',
        ) );

        if ( count( $page_links ) == 0 ) {
            return;
        }

        $links = "<ul class='pagination'>\n\t<li>";
        $links .= join( "</li>\n\t<li>", $page_links );
        $links .= "</li>\n</ul>\n";

        return $links;
    }
}

/**
 * GET POST THUMBNAIL
 */
if ( !function_exists( 'itcode_post_thumbnail' ) ) {
    function itcode_post_thumbnail( $size ) {
        $html   = '';
        $width  = '';
        $height = '';
        global $itcode_image_size;
        if ( isset( $itcode_image_size[$size] ) ) {
            $width  = $itcode_image_size[$size]['width'];
            $height = $itcode_image_size[$size]['height'];
        }

        switch ( get_post_format() ) {
            case 'image':
                $args  = array(
                    'size'     => $size,
                    'meta_key' => 'itcode_post_format_image',
                );
                $image = itcode_get_image( $args );
                if ( !$image ) {
                    break;
                }
                $html = itcode_get_image_hover( $image, $size, get_permalink(), the_title_attribute( 'echo=0' ), get_the_ID() );
                break;
            case 'gallery':
                $images = itcode_get_post_meta( get_the_ID(), 'itcode_post_format_gallery' );
                if ( count( $images ) > 0 ) {
                    $data_plugin_options = "data-plugin-options='{\"singleItem\" : true, \"pagination\" : false, \"navigation\" : true, \"autoHeight\" : true, \"autoPlay\" : true}'";
                    $html                = "<div class='owl-carousel' $data_plugin_options>";
                    foreach ( $images as $image ) {

                        if ( empty( $width ) || empty( $height ) ) {
                            $image_src_arr = wp_get_attachment_image_src( $image, $size );
                            if ( $image_src_arr ) {
                                $image_src = $image_src_arr[0];
                            }
                        } else {
                            $image_src = matthewruddy_image_resize_id( $image, $width, $height );
                        }

                        if ( !empty( $image_src ) ) {
                            $html .= itcode_get_image_hover( $image_src, $size, get_permalink(), the_title_attribute( 'echo=0' ), get_the_ID(), 1 );
                        }
                    }
                    $html .= '</div>';
                } else {
                    $args  = array(
                        'size'     => $size,
                        'meta_key' => '',
                    );
                    $image = itcode_get_image( $args );
                    if ( !$image ) {
                        break;
                    }
                    $html = itcode_get_image_hover( $image, $size, get_permalink(), the_title_attribute( 'echo=0' ), get_the_ID() );
                }
                break;
            case 'video':
                $video = itcode_get_post_meta( get_the_ID(), 'itcode_post_format_video' );
                if ( count( $video ) > 0 ) {
                    $html .= '<div class="embed-responsive embed-responsive-16by9 embed-responsive-' . $size . '">';
                    $video = $video[0];
                    // If URL: show oEmbed HTML
                    if ( filter_var( $video, FILTER_VALIDATE_URL ) ) {
                        $args = array(
                            'wmode' => 'transparent',
                        );
                        $html .= wp_oembed_get( $video, $args );
                    }// If embed code: just display
                    else {
                        $html .= $video;
                    }
                    $html .= '</div>';
                }
                break;
            case 'audio':
                $audio = itcode_get_post_meta( get_the_ID(), 'itcode_post_format_audio' );
                if ( count( $audio ) > 0 ) {
                    $audio = $audio[0];
                    if ( filter_var( $audio, FILTER_VALIDATE_URL ) ) {
                        $html .= wp_oembed_get( $audio );
                        $title = esc_attr( get_the_title() );
                        $audio = esc_url( $audio );
                        if ( empty( $html ) ) {
                            $id = uniqid();
                            $html .= "<div data-player='$id' class='jp-jplayer' data-audio='$audio' data-title='$title'></div>";
                            $html .= itcode_jplayer( $id );
                        }
                    } else {
                        $html .= $audio;
                    }
                    $html .= '<div style="clear:both;"></div>';
                }
                break;
            default:
                $args  = array(
                    'size'     => $size,
                    'meta_key' => '',
                );
                $image = itcode_get_image( $args );
                if ( !$image ) {
                    break;
                }
                $html = itcode_get_image_hover( $image, $size, get_permalink(), the_title_attribute( 'echo=0' ), get_the_ID() );
                break;
        }

        return $html;
    }
}// end function itcode_post_thumbnail

/**
 * GET POST IMAGE
 */
if ( !function_exists( 'itcode_get_image' ) ) {
    function itcode_get_image( $args ) {
        $default = apply_filters(
            'itcode_get_image_default_args',
            array(
                'post_id'  => get_the_ID(),
                'size'     => '',
                'width'    => '',
                'height'   => '',
                'attr'     => '',
                'meta_key' => '',
                'scan'     => false,
                'default'  => ''
            )
        );

        $args = wp_parse_args( $args, $default );
        $size = $args['size'];

        $width  = '';
        $height = '';

        global $itcode_image_size;
        if ( isset( $itcode_image_size[$size] ) ) {
            $width  = $itcode_image_size[$size]['width'];
            $height = $itcode_image_size[$size]['height'];
        }

        if ( !$args['post_id'] ) {
            $args['post_id'] = get_the_ID();
        }

        // Get image from cache
        $key         = md5( serialize( $args ) );
        $image_cache = wp_cache_get( $args['post_id'], 'itcode_get_image' );

        if ( !is_array( $image_cache ) ) {
            $image_cache = array();
        }

        if ( empty( $image_cache[$key] ) ) {

            $image_src = '';

            // Get post thumbnail
            if ( has_post_thumbnail( $args['post_id'] ) ) {
                $post_thumbnail_id = get_post_thumbnail_id( $args['post_id'] );

                if ( empty( $width ) || empty( $height ) ) {
                    $image_src_arr = wp_get_attachment_image_src( $post_thumbnail_id, $size );
                    if ( $image_src_arr ) {
                        $image_src = $image_src_arr[0];
                    }
                } else {
                    $image_src = matthewruddy_image_resize_id( $post_thumbnail_id, $width, $height );
                }
            }

            // Get the first image in the custom field
            if ( ( !isset( $image_src ) || empty( $image_src ) ) && $args['meta_key'] ) {
                $post_thumbnail_id = itcode_get_post_meta( $args['post_id'], $args['meta_key'], true );
                if ( $post_thumbnail_id ) {

                    if ( empty( $width ) || empty( $height ) ) {
                        $image_src_arr = wp_get_attachment_image_src( $post_thumbnail_id, $size );
                        if ( $image_src_arr ) {
                            $image_src = $image_src_arr[0];
                        }
                    } else {
                        $image_src = matthewruddy_image_resize_id( $post_thumbnail_id, $width, $height );
                    }
                }
            }

            // Get the first image in the post content
            if ( ( !isset( $image_src ) || empty( $image_src ) ) && ( $args['scan'] ) ) {
                preg_match( '|<img.*?src=[\'"](.*?)[\'"].*?>|i', get_post_field( 'post_content', $args['post_id'] ), $matches );
                if ( !empty( $matches ) ) {
                    $image_src = $matches[1];
                }
            }

            // Use default when nothing found
            if ( ( !isset( $image_src ) || empty( $image_src ) ) && !empty( $args['default'] ) ) {
                if ( is_array( $args['default'] ) ) {
                    $image_src = @$args['src'];
                } else {
                    $image_src = $args['default'];
                }
            }

            if ( !isset( $image_src ) || empty( $image_src ) ) {
                return false;
            }
            $image_cache[$key] = $image_src;
            wp_cache_set( $args['post_id'], $image_cache, 'itcode_get_image' );
        } else {
            $image_src = $image_cache[$key];
        }
        $image_src = apply_filters( 'itcode_get_image', $image_src, $args );

        return $image_src;
    }
}// end function itcode_get_image

/*================================================
GET IMAGE HOVER
================================================== */
if ( !function_exists( 'itcode_get_image_hover' ) ) {
    function itcode_get_image_hover( $image, $size, $url, $title, $post_id, $gallery = 0 ) {
        $attachment_id = itcode_get_attachment_id_from_url( $image );

        $image_full_arr = wp_get_attachment_image_src( $attachment_id, 'full' );

        $image_full = $image;

        if ( isset( $image_full_arr ) ) {
            $image_full = $image_full_arr[0];
        }

        $width  = '';
        $height = '';

        global $itcode_image_size;
        if ( isset( $itcode_image_size[$size] ) ) {
            $width  = $itcode_image_size[$size]['width'];
            $height = $itcode_image_size[$size]['height'];
        } else {
            global $_wp_additional_image_sizes;
            if ( in_array( $size, array( 'thumbnail', 'medium', 'large' ) ) ) {
                $width  = get_option( $size . '_size_w' );
                $height = get_option( $size . '_size_h' );

            } elseif ( isset( $_wp_additional_image_sizes[$size] ) ) {
                $width  = $_wp_additional_image_sizes[$size]['width'];
                $height = $_wp_additional_image_sizes[$size]['height'];
            }
        }

        $prettyPhoto = 'prettyPhoto';
        if ( $gallery == 1 ) {
            $prettyPhoto = 'prettyPhoto[blog_' . $post_id . ']';
        }
        if ( empty( $width ) || empty( $height ) ) {
            return sprintf( '<div class="entry-thumbnail">
                        <a href="%1$s" title="%2$s" class="entry-thumbnail_overlay">
                            <img class="img-thumbnail" src="%3$s" alt="%2$s"/>
                        </a>
                        <a data-rel="%5$s" href="%4$s" class="prettyPhoto"><i class="fa fa-eye"></i></a>
                      </div>',
                $url,
                $title,
                $image,
                $image_full,
                $prettyPhoto
            );
        } else {
            return sprintf( '<div class="entry-thumbnail">
                        <a href="%1$s" title="%2$s" class="entry-thumbnail_overlay">
                            <img width="%6$s" height="%7$s" class="img-thumbnail" src="%3$s" alt="%2$s"/>
                        </a>
                        <a data-rel="%5$s" href="%4$s" class="prettyPhoto"><i class="fa fa-eye"></i></a>
                      </div>',
                $url,
                $title,
                $image,
                $image_full,
                $prettyPhoto,
                $width,
                $height
            );
        }

    }
}


/*================================================
GET ATTACHMENT ID FROM URL
================================================== */
if ( !function_exists( 'itcode_get_attachment_id_from_url' ) ) {
    function itcode_get_attachment_id_from_url( $attachment_url = '' ) {
        global $wpdb;
        $attachment_id = false;

        // If there is no url, return.
        if ( '' == $attachment_url ) {
            return;
        }

        // Get the upload directory paths
        $upload_dir_paths = wp_upload_dir();

        // Make sure the upload path base directory exists in the attachment URL, to verify that we're working with a media library image
        if ( false !== strpos( $attachment_url, $upload_dir_paths['baseurl'] ) ) {

            // If this is the URL of an auto-generated thumbnail, get the URL of the original image
            $attachment_url = preg_replace( '/-\d+x\d+(?=\.(jpg|jpeg|png|gif)$)/i', '', $attachment_url );

            // Remove the upload path base directory from the attachment URL
            $attachment_url = str_replace( $upload_dir_paths['baseurl'] . '/', '', $attachment_url );

            // Finally, run a custom database query to get the attachment ID from the modified attachment URL
            $attachment_id = $wpdb->get_var( $wpdb->prepare( "SELECT wposts.ID FROM $wpdb->posts wposts, $wpdb->postmeta wpostmeta WHERE wposts.ID = wpostmeta.post_id AND wpostmeta.meta_key = '_wp_attached_file' AND wpostmeta.meta_value = '%s' AND wposts.post_type = 'attachment'", $attachment_url ) );

        }

        return $attachment_id;
    }
}

/*================================================
GET JPLAYER
================================================== */
if ( !function_exists( 'itcode_jplayer' ) ) {
    function itcode_jplayer( $id = 'jp_container_1' ) {
        ?>
        <div id="<?php echo esc_attr( $id ); ?>" class="jp-audio">
            <div class="jp-type-playlist">
                <div class="jp-gui jp-interface">
                    <ul class="jp-controls jp-play-pause">
                        <li><a href="javascript:" class="jp-play" tabindex="1"><i
                                    class="fa fa-play"></i> <?php echo esc_html__( 'play', 'itcode' ); ?></a></li>
                        <li><a href="javascript:" class="jp-pause" tabindex="1"><i
                                    class="fa fa-pause"></i> <?php echo esc_html__( 'pause', 'itcode' ); ?></a></li>
                    </ul>

                    <div class="jp-progress">
                        <div class="jp-seek-bar">
                            <div class="jp-play-bar"></div>
                        </div>
                    </div>

                    <ul class="jp-controls jp-volume">
                        <li>
                            <a href="javascript:;" class="jp-mute" tabindex="1" title="mute"><i
                                    class="fa  fa-volume-up"></i> <?php echo esc_html__( 'mute', 'itcode' ); ?></a>
                        </li>
                        <li>
                            <a href="javascript:;" class="jp-unmute" tabindex="1" title="unmute"><i
                                    class="fa fa-volume-off"></i><?php echo esc_html__( 'unmute', 'itcode' ); ?></a>
                        </li>
                        <li>
                            <div class="jp-volume-bar">
                                <div class="jp-volume-bar-value"></div>
                            </div>
                        </li>

                    </ul>

                    <div class="jp-time-holder">
                        <div class="jp-current-time"></div>
                        <div class="jp-duration"></div>
                    </div>
                    <ul class="jp-toggles">
                        <li>
                            <a href="javascript:;" class="jp-shuffle" tabindex="1"
                               title="shuffle"><?php echo esc_html__( 'shuffle', 'itcode' ); ?></a>
                        </li>
                        <li>
                            <a href="javascript:" class="jp-shuffle-off" tabindex="1"
                               title="shuffle off"><?php echo esc_html__( 'shuffle off', 'itcode' ); ?></a>
                        </li>
                        <li>
                            <a href="javascript:;" class="jp-repeat" tabindex="1"
                               title="repeat"><?php echo esc_html__( 'repeat', 'itcode' ); ?></a>
                        </li>
                        <li>
                            <a href="javascript:;" class="jp-repeat-off" tabindex="1"
                               title="repeat off"><?php echo esc_html__( 'repeat off', 'itcode' ); ?></a>
                        </li>
                    </ul>
                </div>

                <div class="jp-no-solution">
                    <?php printf( __( '<span>Update Required</span> To play the media you will need to either update your browser to a recent version or update your <a href="%s" target="_blank">Flash plugin</a>.', 'itcode' ), 'http://get.adobe.com/flashplayer/' ); ?>
                </div>
            </div>
        </div>
        <?php
    }
}

/*================================================
GET POST DATE
================================================== */
if ( !function_exists( 'itcode_post_date' ) ) {
    function itcode_post_date() {
        get_template_part( 'template-parts/archive/post-date' );
    }
}

/*================================================
GET POST META
================================================== */
if ( !function_exists( 'itcode_post_meta' ) ) {
    function itcode_post_meta() {
        get_template_part( 'template-parts/post-meta' );
    }
}

/*================================================
GET POST META FOOTER
================================================== */
if ( !function_exists( 'itcode_post_meta_footer' ) ) {
    function itcode_post_meta_footer() {
        get_template_part( 'template-parts/archive/post-meta-footer' );
    }
}
/*================================================
GET POST META SMALL
================================================== */
if ( !function_exists( 'itcode_post_meta_small' ) ) {
    function itcode_post_meta_small() {
        get_template_part( 'template-parts/archive/post-meta-small' );
    }
}

/**
 * Loop reset
 */
if ( !function_exists( 'itcode_loop_reset' ) ) {
    function itcode_loop_reset() {
        global $itcode_loop;
        $itcode_loop[] = '';
    }
}

/*================================================
POST NAV
================================================== */
if ( !function_exists( 'itcode_post_nav' ) ) {
    function itcode_post_nav() {
        get_template_part( 'template-parts/single-blog/post-nav' );
    }

    add_action( 'itcode_after_single_post_content', 'itcode_post_nav', 20 );
}

/*================================================
LINK PAGES
================================================== */
if ( !function_exists( 'itcode_link_pages' ) ) {
    function itcode_link_pages() {
        wp_link_pages( array(
            'before'      => '<div class="itcode-page-links"><span class="itcode-page-links-title">' . esc_html__( 'Pages:', 'itcode' ) . '</span>',
            'after'       => '</div>',
            'link_before' => '<span class="itcode-page-link">',
            'link_after'  => '</span>',
        ) );
    }

    add_action( 'itcode_after_single_post_content', 'itcode_link_pages', 5 );
}

/*================================================
POST TAGS
================================================== */
/*if ( !function_exists( 'itcode_post_tags' ) ) {
    function itcode_post_tags() {
        get_template_part( 'template-parts/single-blog/post-tags' );
    }

    add_action( 'itcode_after_single_post_content', 'itcode_post_tags', 10 );
}*/

/*================================================
SHARE
================================================== */
/*if ( !function_exists( 'itcode_share' ) ) {
    function itcode_share() {
        get_template_part( 'template-parts/social-share' );
    }

    add_action( 'itcode_after_single_post_content', 'itcode_share', 15 );
}*/
/*================================================
Author
================================================== */
/*if ( !function_exists( 'itcode_author' ) ) {
    function itcode_author() {
        get_template_part( 'template-parts/single-blog/post-author' );
    }

    add_action( 'itcode_after_single_post_content', 'itcode_share', 15 );
}*/

/*================================================
RENDER COMMENTS
================================================== */
if ( !function_exists( 'itcode_render_comments' ) ) {
    function itcode_render_comments( $comment, $args, $depth ) {
        $GLOBALS['comment'] = $comment; ?>
        <li <?php comment_class('list-group-item'); ?> id="li-comment-<?php comment_ID() ?>">

        <div id="comment-<?php comment_ID(); ?>" class="media comment-body clearfix">
            <div class="d-flex mr-3 comment-avatar-wrap">
                <?php echo get_avatar( $comment, $args['avatar_size'] ); ?>
            </div>

            <div class="media-body comment-text">
                <div class="mt-0 author">
                    <div class="author-name"><?php printf( __( '%s', 'itcode' ), get_comment_author_link() ) ?></div>
                </div>
                <div class="comment-meta">
                    <span class="comment-meta-date"><?php echo get_comment_date( 'M d, Y \a\t g:i a' ); ?></span>
                    <?php edit_comment_link( esc_html__( 'Edit', 'itcode' ), '<span class="comment-meta-edit">', '</span>' ) ?>
                </div>
                <div class="text"><?php comment_text() ?></div>
                <div class="comment-footer">
                    <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => esc_html__( 'Reply', 'itcode' ) ) ) ) ?>
                </div>
                <?php if ( $comment->comment_approved == '0' ): ?>
                    <em><?php echo esc_html__( 'Your comment is awaiting moderation.', 'itcode' ) ?></em>
                <?php endif; ?>
            </div>
        </div>


        <?php
    }
}

/*================================================
COMMENTS FORM
================================================== */
if ( !function_exists( 'itcode_comment_form' ) ) {
    function itcode_comment_form() {
        $commenter = wp_get_current_commenter();
        $req       = get_option( 'require_name_email' );
        $aria_req  = ( $req ? " aria-required='true'" : '' );
        $html5     = current_theme_supports( 'html5', 'comment-form' ) ? 'html5' : 'xhtml';;
        $fields            = array(
            'author' => '<div class="form-group col-md-12">' .
                '<label for="author">' . esc_html__( 'Name', 'itcode' ) . '</label>' .
                '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" placeholder="' . esc_html__( 'Name', 'itcode' ) . '" ' . $aria_req . '>' .
                '</div>',
            'email'  => '<div class="form-group col-md-12">' .
                '<label for="email">' . esc_html__( 'Email', 'itcode' ) . '</label>' .
                '<input id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_email'] ) . '" placeholder="' . esc_html__( 'Email', 'itcode' ) . '" ' . $aria_req . '>' .
                '</div>',
            'url'    => '<div class="form-group col-md-12">' .
                '<label for="url">' . esc_html__( "Website", "itcode" ) . '</label>' .
                '<input id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" placeholder="' . esc_html__( 'Website', 'itcode' ) . '" />' .
                '</div>'
        );
        $fields            = apply_filters( 'itcode_comment_fields', $fields );
        $comment_form_args = array(
            'fields'               => $fields,
            'comment_field'        => '<div class="form-group col-md-12">' .
                '<label for="comment">' . esc_html__( 'Message', 'itcode' ) . '</label>' .
                '<textarea rows="6" id="comment" name="comment"  placeholder="' . esc_html__( 'Message', 'itcode' ) . '" ' . $aria_req . '>' . esc_attr( $commenter['comment_author_url'] ) . '</textarea>' .
                '</div>',
            'comment_notes_before' => '<p class="comment-notes">' .
                esc_html__( 'Your email address will not be published.', 'itcode' )/* . ( $req ? $required_text : '' ) */ .
                '</p>',
            'comment_notes_after'  => '',
            'id_submit'            => 'btnComment',
            'class_submit'         => 'button-comment',
            'title_reply'          => esc_html__( 'POST YOUR COMMENT', 'itcode' ),
            'title_reply_to'       => esc_html__( 'POST YOUR COMMENT to %s', 'itcode' ),
            'cancel_reply_link'    => esc_html__( 'Cancel reply', 'itcode' ),
            'label_submit'         => esc_html__( 'SEND MESSAGE', 'itcode' )
        );

        $comment_form_args = apply_filters( 'itcode_comment_form_args', $comment_form_args );

        comment_form( $comment_form_args );
    }
}
/*================================================
Post view Count
================================================== */
if ( !function_exists( 'itcode_set_post_views' ) ) {
    function itcode_set_post_views( $postID ) {
        $count_key = 'wpb_post_views_count';
        $count     = get_post_meta( $postID, $count_key, true );
        if ( $count == '' ) {
            $count = 0;
            delete_post_meta( $postID, $count_key );
            add_post_meta( $postID, $count_key, '0' );
        } else {
            $count ++;
            update_post_meta( $postID, $count_key, $count );
        }
    }
}

if ( !function_exists( 'itcode_track_post_views' ) ) {
    function itcode_track_post_views( $post_id ) {
        if ( !is_single() ) {
            return;
        }
        if ( empty( $post_id ) ) {
            global $post;
            $post_id = $post->ID;
        }
        itcode_set_post_views( $post_id );
    }

    add_action( 'wp_head', 'itcode_track_post_views' );
}
if ( !function_exists( 'itcode_get_post_views' ) ) {
    function itcode_get_post_views( $postID ) {
        $count_key = 'wpb_post_views_count';
        $count     = get_post_meta( $postID, $count_key, true );
        if ( $count == '' ) {
            delete_post_meta( $postID, $count_key );
            add_post_meta( $postID, $count_key, '0' );

            return "0";
        }

        return $count;
    }
}



add_action( 'show_user_profile', 'itcode_extra_profile_fields' );
add_action( 'edit_user_profile', 'itcode_extra_profile_fields' );

function itcode_extra_profile_fields( $user ) { ?>

    <h3>Extra profile information</h3>

    <table class="form-table">

        <tr>
            <th><label for="facebook">Facebook</label></th>

            <td>
                <input type="text" name="facebook" id="facebook" value="<?php echo esc_attr( get_the_author_meta( 'facebook', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description">Please enter your facebook.</span>
            </td>
        </tr>

        <tr>
            <th><label for="twitter">Twitter</label></th>

            <td>
                <input type="text" name="twitter" id="twitter" value="<?php echo esc_attr( get_the_author_meta( 'twitter', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description">Please enter your Twitter.</span>
            </td>
        </tr>

        <tr>
            <th><label for="flickr">Flickr</label></th>

            <td>
                <input type="text" name="flickr" id="flickr" value="<?php echo esc_attr( get_the_author_meta( 'flickr', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description">Please enter your Flickr.</span>
            </td>
        </tr>
        <tr>
            <th><label for="linkedin">Linkedin</label></th>

            <td>
                <input type="text" name="linkedin" id="linkedin" value="<?php echo esc_attr( get_the_author_meta( 'linkedin', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description">Please enter your Linkedin.</span>
            </td>
        </tr>

    </table>
<?php }

add_action( 'personal_options_update', 'my_save_extra_profile_fields' );
add_action( 'edit_user_profile_update', 'my_save_extra_profile_fields' );

function my_save_extra_profile_fields( $user_id ) {

    if ( !current_user_can( 'edit_user', $user_id ) ) {
        return false;
    }

    /* Copy and paste this line for additional fields. Make sure to change 'twitter' to the field ID. */
    update_user_meta( $user_id, 'facebook', $_POST['facebook'] );
    update_user_meta( $user_id, 'twitter', $_POST['twitter'] );
    update_user_meta( $user_id, 'flickr', $_POST['flickr'] );
    update_user_meta( $user_id, 'linkedin', $_POST['linkedin'] );
}




/**
 * Excerpt Length
 */
function itcode_excerpt_length($length) {
    return get_theme_mod('archive_blog_excerpt_large', 50 );
}//end
add_filter('excerpt_length', 'itcode_excerpt_length', 999);
/**
 *
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a custom text link.
 *
 * @return string link.
 */
function itcode_excerpt_more($more) {
    global $post;
    return ' <a class="read-more" href="' . get_permalink( $post->ID ) . '"><i class="fa fa-eye"></i> '.get_theme_mod('archive_blog_readmore_text', 'Continue Reading').' ...</a>';
}//end
add_filter('excerpt_more', 'itcode_excerpt_more');



/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 *
 * @since Twenty Seventeen 1.0
 *
 * @return string 'Continue reading' link prepended with an ellipsis.
 */
/*function itcode_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	$link = sprintf( '<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		/*sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'itcode' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'itcode_excerpt_more' );*/

/*function itcode_excerpt($limit) {
    $excerpt = explode(' ', get_the_excerpt(), $limit);
    if (count($excerpt)>=$limit) {
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt).'...';
    } else {
        $excerpt = implode(" ",$excerpt);
    }
    return $excerpt;
}//end*/


if ( !function_exists( 'excerpt' ) ) {
    function excerpt( $limit ) {
        $content = get_the_excerpt();
        $content = apply_filters( 'the_content', $content );
        $content = str_replace( ']]>', ']]&gt;', $content );
        $content = explode( ' ', $content, $limit );
        array_pop( $content );
        $content = implode( " ", $content );

        return $content;
    }
}

/*function itcode_my_excerpt($text, $excerpt){
    if ($excerpt) return $excerpt;
    $text = strip_shortcodes( $text );
    $text = apply_filters('the_content', $text);
    $text = str_replace(']]>', ']]&gt;', $text);
    $text = strip_tags($text);
    $excerpt_length = apply_filters('excerpt_length', 55);
    $excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
    $words = preg_split("/[\n
	 ]+/", $text, $excerpt_length + 1, PREG_SPLIT_NO_EMPTY);
    if ( count($words) > $excerpt_length ) {
        array_pop($words);
        $text = implode(' ', $words);
        $text = $text . $excerpt_more;
    } else {
        $text = implode(' ', $words);
    }
    return apply_filters('wp_trim_excerpt', $text, $excerpt);
}// end*/




//add_filter('the_content_more_link', 'itcode_excerpt_more');

///////////////////////////////////



/**
 * get nav menu list
 */
if ( !function_exists( 'itcode_get_nav_menu_list' ) ) {
    function itcode_get_nav_menu_list() {

        if ( !is_admin() ) { return array(); }

        $menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );

        $menu_list = array();

        foreach ( $menus as $menu ) {
            $menu_list[$menu->term_id] = $menu->name;
        }

        return $menu_list;
    }
}

/**
 * get sidebars list
 */
if ( !function_exists( 'itcode_get_sidebars_list' ) ) {
    function itcode_get_sidebars_list() {
        global $wp_registered_sidebars;

        $sidebar_list = array();
        if (!empty($wp_registered_sidebars)) {
            foreach ($wp_registered_sidebars as $sidebar) {
                // todo rename
                $sidebar_list[$sidebar['id']] = $sidebar['name'];
            }
        };

        //var_dump($sidebar_list);
        return $sidebar_list;
    }
}


/**
 *  LOGIN
 */
if ( !function_exists( 'itcode_login' ) ) {
    function itcode_login() {
        global $user_ID, $user_identity;
        if ($user_ID) { ?>

            <div class="row">
                <div class="col-sm-2 col-md-2">
                    <div class="thumbnail">
                        <a  class="" href="<?php echo esc_url(home_url('/wp-admin/profile.php')); ?>">
                            <?php echo get_avatar( $user_ID, $size = '50', '', '', array( 'class' => 'media-object')); ?>
                        </a>
                    </div>
                </div>
                <div class="col-sm-9 col-md-9">
                    <div class="caption">
                        <ul class="logged-links nav nav-pills">
                            <li><a href="<?php echo esc_url(home_url('/wp-admin/')); ?>"><?php esc_html_e('Dashboard','itcode'); ?> </a></li>
                            <li><a href="<?php echo esc_url(home_url('/wp-admin/profile.php')); ?>"><?php esc_html_e('My Profile','itcode'); ?> </a></li>
                            <li><a href="<?php echo esc_url(wp_logout_url(get_permalink())); ?>"><?php esc_html_e('Logout','itcode'); ?> </a></li>
                        </ul>
                    </div>
                </div>
            </div>

        <?php }else{ ?>
            <div class="row">
                <div class="col-sm-12 col-md-12">
                    <h3 class="user-login-title"><?php esc_html_e( 'Account Login', 'itcode' ); ?></h3>
                    <div id="user-login">
                        <?php wp_login_form(array('label_username' => esc_html__( 'Username','itcode' ),'label_password' => esc_html__( 'Password','itcode' ),'label_remember' => esc_html__( 'Remember Me','itcode' ),
                            'label_log_in'   => esc_html__( 'Log In','itcode' ),));?>
                        <ul class="login-links">
                            <?php if ( get_option('users_can_register') ) : ?><?php echo wp_register() ?><?php endif; ?>
                            <li><a href="<?php echo esc_url(wp_lostpassword_url(get_permalink()))?>"><?php esc_html_e('Foreget Password?','itcode'); ?></a></li>
                        </ul>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}//end login



/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since Twenty Seventeen 1.0
 */
function itcode_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'itcode_javascript_detection', 0 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
/*function itcode_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", get_bloginfo( 'pingback_url' ) );
	}
}
add_action( 'wp_head', 'itcode_pingback_header' );*/

/**
 * Display custom color CSS.
 */
function itcode_colors_css_wrap() {
	if ( 'custom' !== get_theme_mod( 'colorscheme' ) && ! is_customize_preview() ) {
		return;
	}

	require_once( get_parent_theme_file_path( '/inc/color-patterns.php' ) );
	$hue = absint( get_theme_mod( 'colorscheme_hue', 250 ) );
?>
	<style type="text/css" id="custom-theme-colors" <?php if ( is_customize_preview() ) { echo 'data-hue="' . $hue . '"'; } ?>>
		<?php echo itcode_custom_colors_css(); ?>
	</style>
<?php }
add_action( 'wp_head', 'itcode_colors_css_wrap' );



/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for content images.
 *
 * @since Twenty Seventeen 1.0
 *
 * @param string $sizes A source size value for use in a 'sizes' attribute.
 * @param array  $size  Image size. Accepts an array of width and height
 *                      values in pixels (in that order).
 * @return string A source size value for use in a content image 'sizes' attribute.
 */
function itcode_content_image_sizes_attr( $sizes, $size ) {
	$width = $size[0];

	if ( 740 <= $width ) {
		$sizes = '(max-width: 706px) 89vw, (max-width: 767px) 82vw, 740px';
	}

	if ( is_active_sidebar( 'sidebar-1' ) || is_archive() || is_search() || is_home() || is_page() ) {
		if ( ! ( is_page() && 'one-column' === get_theme_mod( 'page_options' ) ) && 767 <= $width ) {
			 $sizes = '(max-width: 767px) 89vw, (max-width: 1000px) 54vw, (max-width: 1071px) 543px, 580px';
		}
	}

	return $sizes;
}
add_filter( 'wp_calculate_image_sizes', 'itcode_content_image_sizes_attr', 10, 2 );

/**
 * Filter the `sizes` value in the header image markup.
 *
 * @since Twenty Seventeen 1.0
 *
 * @param string $html   The HTML image tag markup being filtered.
 * @param object $header The custom header object returned by 'get_custom_header()'.
 * @param array  $attr   Array of the attributes for the image tag.
 * @return string The filtered header image HTML.
 */
function itcode_header_image_tag( $html, $header, $attr ) {
	if ( isset( $attr['sizes'] ) ) {
		$html = str_replace( $attr['sizes'], '100vw', $html );
	}
	return $html;
}
add_filter( 'get_header_image_tag', 'itcode_header_image_tag', 10, 3 );

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for post thumbnails.
 *
 * @since Twenty Seventeen 1.0
 *
 * @param array $attr       Attributes for the image markup.
 * @param int   $attachment Image attachment ID.
 * @param array $size       Registered image size or flat array of height and width dimensions.
 * @return string A source size value for use in a post thumbnail 'sizes' attribute.
 */
function itcode_post_thumbnail_sizes_attr( $attr, $attachment, $size ) {
	if ( is_archive() || is_search() || is_home() ) {
		$attr['sizes'] = '(max-width: 767px) 89vw, (max-width: 1000px) 54vw, (max-width: 1071px) 543px, 580px';
	} else {
		$attr['sizes'] = '100vw';
	}

	return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'itcode_post_thumbnail_sizes_attr', 10, 3 );

/**
 * Use front-page.php when Front page displays is set to a static page.
 *
 * @since Twenty Seventeen 1.0
 *
 * @param string $template front-page.php.
 *
 * @return string The template to be used: blank if is_home() is true (defaults to index.php), else $template.
 */
function itcode_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'itcode_front_page_template' );



