<?php
/**
 * Add WooCommerce support
 *
 * @package itcode
 */


if ( class_exists( 'WooCommerce' ) ) {
	/*================================================
	FILTER HOOK
	================================================== */
	remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
	add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 5 );


	/*================================================
	RESET LOOP
	================================================== */
	if ( !function_exists( 'itcode_woocommerce_reset_loop' ) ) {
		function itcode_woocommerce_reset_loop() {
			global $itcode_woocommerce_loop;
			$itcode_woocommerce_loop['layout']         = '';
			$itcode_woocommerce_loop['single_columns'] = '';
			$itcode_woocommerce_loop['columns']        = '';
		}
	}

	/*================================================
	LOOP CATEGORY TEMPLATE
	================================================== */
	if ( !function_exists( 'itcode_woocommerce_template_loop_category' ) ) {
		function itcode_woocommerce_template_loop_category() {
			wc_get_template( 'loop/category.php' );
		}

		add_action( 'woocommerce_after_shop_loop_item_title', 'itcode_woocommerce_template_loop_category', 1 );
	}

	/*================================================
	LOOP NAME TEMPLATE
	================================================== */
	if ( !function_exists( 'itcode_woocommerce_template_loop_name' ) ) {
		function itcode_woocommerce_template_loop_name() {
			wc_get_template( 'loop/name.php' );
		}

		add_action( 'woocommerce_after_shop_loop_item_title', 'itcode_woocommerce_template_loop_name', 1 );
	}

	/*================================================
	LOOP LINK TEMPLATE
	================================================== */
	if ( !function_exists( 'itcode_woocomerce_template_loop_link' ) ) {
		function itcode_woocomerce_template_loop_link() {
			wc_get_template( 'loop/link.php' );
		}

		add_action( 'woocommerce_before_shop_loop_item_title', 'itcode_woocomerce_template_loop_link', 20 );
	}

	/*================================================
	QUICK VIEW TEMPLATE
	================================================== */
	if ( !function_exists( 'itcode_woocomerce_template_loop_quick_view' ) ) {
		function itcode_woocomerce_template_loop_quick_view() {
			wc_get_template( 'loop/quick-view.php' );
		}

		add_action( 'woocommerce_before_shop_loop_item_title', 'itcode_woocomerce_template_loop_quick_view', 15 );
	}


	/*================================================
	FILTER PRODUCTS PER PAGE
	================================================== */
	if ( !function_exists( 'itcode_show_products_per_page' ) ) {
		function itcode_show_products_per_page() {
			$product_per_page = get_itcode_options('product_per_page');
			if ( empty( $product_per_page ) ) {
				$product_per_page = 12;
			}
			$page_size = isset( $_GET['page_size'] ) ? wc_clean( $_GET['page_size'] ) : $product_per_page;

			return $page_size;
		}

		add_filter( 'loop_shop_per_page', 'itcode_show_products_per_page' );
	}


    if ( !function_exists( 'hook_itcode_grid_list_trigger' ) ) {
        function hook_itcode_grid_list_trigger(){  ?>
            <div class="display">
                <a class="btn btn-secondary btn-sm list-trigger"><i class="fa fa-list"></i></a>
                <a class="btn btn-secondary btn-sm grid-trigger"><i class="fa fa-th"></i></a>
            </div>
            <?php

        }
        add_action('woocommerce_before_shop_loop','hook_itcode_grid_list_trigger',11);
    }


	/*================================================
	OVERWRITE LOOP PRODUCT THUMBNAIL
	================================================== */
	if ( !function_exists( 'woocommerce_template_loop_product_thumbnail' ) ) {
		/**
		 * Get the product thumbnail for the loop.
		 *
		 * @access        public
		 * @subpackage    Loop
		 * @return void
		 */
		function woocommerce_template_loop_product_thumbnail() {
			global $post, $product;
			$attachment_ids  = $product->get_gallery_attachment_ids();
			//var_dump($attachment_ids);
            /**
             * array(1) {
             *   [0]=>  string(2) "98"
             * }
             */
			$secondary_image = '';
			$class           = 'product-thumb-one';
			if ( array_key_exists( 0 , $attachment_ids)  ) { // bugfix if not secondary img
				$secondary_image_id = $attachment_ids['0'];
				$secondary_image    = wp_get_attachment_image( $secondary_image_id, apply_filters( 'shop_catalog', 'shop_catalog' ) );
				if ( !empty( $secondary_image ) ) {
					$class = 'product-thumb-primary';
				}
			}
			?>
			<?php if ( has_post_thumbnail() ) : ?>
				<div class="<?php echo esc_attr( $class ); ?>">
					<?php $thumb = woocommerce_get_product_thumbnail();
					    if (!empty($thumb)){
					        echo $thumb;
                        }else{
                            echo apply_filters( 'woocommerce_single_product_image_html', sprintf( '<img src="%s" alt="%s" />', wc_placeholder_img_src(), __( 'Placeholder', 'woocommerce' ) ), $post->ID );
                        }

					?>
				</div>
				<?php if ( !empty( $secondary_image ) ) : ?>
					<div class="product-thumb-secondary">
						<?php echo wp_kses_post( $secondary_image ); ?>
					</div>
				<?php endif; ?>
            <?php else : ?>
                <?php echo apply_filters( 'woocommerce_single_product_image_html', sprintf( '<img src="%s" alt="%s" />', wc_placeholder_img_src(), __( 'Placeholder', 'woocommerce' ) ), $post->ID ); ?>
            <?php endif; ?>
			<?php
		}
	}

	/*================================================
	PRODUCT NEWS
	================================================== */
	if ( !function_exists( 'itcode_woocommerce_add_custom_general_fields' ) ) {
		function itcode_woocommerce_add_custom_general_fields() {
			echo '<div class="options_group">';
			woocommerce_wp_checkbox(
				array(
					'id'    => 'itcode_product_new',
					'label' => esc_html__( 'Product New', 'itcode' )
				)
			);
			echo '</div>';
		}

		add_action( 'woocommerce_product_options_general_product_data', 'itcode_woocommerce_add_custom_general_fields' );
	}

	if ( !function_exists( 'itcode_woo_add_custom_general_fields_save' ) ) {
		function itcode_woo_add_custom_general_fields_save( $post_id ) {
			$itcode_product_new = isset( $_POST['itcode_product_new'] ) ? 'yes' : 'no';
			update_post_meta( $post_id, 'itcode_product_new', $itcode_product_new );
		}

		add_action( 'woocommerce_process_product_meta', 'itcode_woo_add_custom_general_fields_save' );
	}

	if ( !function_exists( 'itcode_columns_into_product_list' ) ) {
		function itcode_columns_into_product_list( $defaults ) {
			$defaults['itcode_product_new'] = 'New';

			return $defaults;
		}

		add_filter( 'manage_edit-product_columns', 'itcode_columns_into_product_list' );
	}

	if ( !function_exists( 'itcode_column_into_product_list' ) ) {
		function itcode_column_into_product_list( $column, $post_id ) {
			switch ( $column ) {
				case 'itcode_product_new':
					echo get_post_meta( $post_id, 'itcode_product_new', true );
					break;
			}
		}

		add_action( 'manage_product_posts_custom_column', 'itcode_column_into_product_list', 10, 2 );
	}

	if ( !function_exists( 'itcode_sortable_columns' ) ) {
		function itcode_sortable_columns() {
			return array(
				'itcode_product_new' => 'itcode_product_new'
			);
		}

		add_filter( "manage_edit-product_sortable_columns", "itcode_sortable_columns" );
	}

	if ( !function_exists( 'itcode_event_column_orderby' ) ) {
		function itcode_event_column_orderby( $query ) {
			if ( !is_admin() ) {
				return;
			}
			$orderby = $query->get( 'orderby' );
			if ( 'itcode_product_new' == $orderby ) {
				$query->set( 'meta_key', 'itcode_product_new' );
				$query->set( 'orderby', 'meta_value_num' );
			}
		}

		add_action( 'pre_get_posts', 'itcode_event_column_orderby' );
	}


	/*================================================
	SINGLE PRODUCT
	================================================== */
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
	add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 15 );

	if ( !function_exists( 'itcode_product_description_heading' ) ) {
		function itcode_product_description_heading() {
			return '';
		}
	}
	add_filter( 'woocommerce_product_description_heading', 'itcode_product_description_heading' );
	add_filter( 'woocommerce_product_additional_information_heading', 'itcode_product_description_heading' );


	if ( !function_exists( 'itcode_related_products_args' ) ) {
		function itcode_related_products_args() {
			$args['posts_per_page'] = !empty( get_itcode_options('related_product_count') ) ? get_itcode_options('related_product_count') : 8;

			return $args;
		}

		add_filter( 'woocommerce_output_related_products_args', 'itcode_related_products_args' );
	}

	if ( !function_exists( 'itcode_woocommerce_product_related_posts_relate_by_category' ) ) {
		function itcode_woocommerce_product_related_posts_relate_by_category() {

			return get_itcode_options('related_product_condition','category') == 1 ? true : false;
		}

		add_filter( 'woocommerce_product_related_posts_relate_by_category', 'itcode_woocommerce_product_related_posts_relate_by_category' );
	}

	if ( !function_exists( 'itcode_woocommerce_product_related_posts_relate_by_tag' ) ) {
		function itcode_woocommerce_product_related_posts_relate_by_tag() {
			return get_itcode_options('related_product_condition','tag') == 1 ? true : false;
		}

		add_filter( 'woocommerce_product_related_posts_relate_by_tag', 'itcode_woocommerce_product_related_posts_relate_by_tag' );
	}


	/*================================================
	SHOPPING CART
	================================================== */
	remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
	add_action( 'woocommerce_after_cart', 'woocommerce_cross_sell_display', 15 );
	add_action( 'woocommerce_before_cart_totals', 'woocommerce_shipping_calculator', 5 );

	if ( !function_exists( 'itcode_button_continue_shopping' ) ) {
		function itcode_button_continue_shopping() {
			$continue_shopping = get_permalink( wc_get_page_id( 'shop' ) );
			?>
			<a href="<?php echo esc_url( $continue_shopping ); ?>" class="continue-shopping button"><?php echo esc_html__( 'Continue shopping', 'itcode' ); ?></a>
			<?php
		}
	}
	if ( !function_exists( 'itcode_woocommerce_sale_flash' ) ) {
		function itcode_woocommerce_sale_flash( $sale_flash, $post, $product ) {
			$product_sale_flash_mode = !empty( get_itcode_options('product_sale_flash_mode') ) ? get_itcode_options('product_sale_flash_mode') : '';
			if ( $product_sale_flash_mode == 'percent' ) {
				$sale_percent = 0;
				if ( $product->is_on_sale() && $product->product_type != 'grouped' ) {
					if ( $product->product_type == 'variable' ) {
						$available_variations = $product->get_available_variations();
						for ( $i = 0; $i < count( $available_variations ); ++ $i ) {
							$variation_id      = $available_variations[$i]['variation_id'];
							$variable_product1 = new WC_Product_Variation( $variation_id );
							$regular_price     = $variable_product1->get_regular_price();
							$sales_price       = $variable_product1->get_sale_price();
							$price             = $variable_product1->get_price();
							if ( $sales_price != $regular_price && $sales_price == $price ) {
								$percentage = round( ( ( ( $regular_price - $sales_price ) / $regular_price ) * 100 ), 1 );
								if ( $percentage > $sale_percent ) {
									$sale_percent = $percentage;
								}
							}
						}
					} else {
						$sale_percent = round( ( ( ( $product->get_regular_price() - $product->get_sale_price() ) / $product->get_regular_price() ) * 100 ), 1 );
					}
				}
				if ( $sale_percent > 0 ) {
					return '<span class="on-sale">' . $sale_percent . '%</span>';
				} else {
					return "";
				}

			}

			return $sale_flash;
		}

		add_filter( 'woocommerce_sale_flash', 'itcode_woocommerce_sale_flash', 10, 3 );
	}


	/*Quick View*/
	add_action( 'itcode_before_quick_view_product_summary', 'woocommerce_show_product_sale_flash', 10 );
	if ( !function_exists( 'itcode_quick_view_product_images' ) ) {
		function itcode_quick_view_product_images() {
			wc_get_template( 'quick-view/product-image.php' );
		}

		add_action( 'itcode_before_quick_view_product_summary', 'itcode_quick_view_product_images', 20 );
	}


	if ( !function_exists( 'itcode_template_quick_view_product_title' ) ) {
		function itcode_template_quick_view_product_title() {
			wc_get_template( 'quick-view/title.php' );
		}

		add_action( 'itcode_quick_view_product_summary', 'itcode_template_quick_view_product_title', 5 );
	}

	if ( !function_exists( 'itcode_template_quick_view_product_rating' ) ) {
		function itcode_template_quick_view_product_rating() {
			wc_get_template( 'quick-view/rating.php' );
		}

		add_action( 'itcode_quick_view_product_summary', 'itcode_template_quick_view_product_rating', 15 );
	}

	add_action( 'itcode_quick_view_product_summary', 'woocommerce_template_single_price', 10 );
	add_action( 'itcode_quick_view_product_summary', 'woocommerce_template_single_excerpt', 20 );
	add_action( 'itcode_quick_view_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
	add_action( 'itcode_quick_view_product_summary', 'woocommerce_template_single_meta', 40 );
	add_action( 'itcode_quick_view_product_summary', 'woocommerce_template_single_sharing', 50 );


}
