<?php
/**
 * Jetpack Compatibility File.
 *
 * @link https://jetpack.com/
 *
 * @package itcode
 */

if ( ! function_exists( 'itcode_jetpack_setup' ) ) {
	/**
	 * Jetpack setup function.
	 *
         * Add theme support for Infinite Scroll.
         * See: https://jetpack.me/support/infinite-scroll/
	 * See: https://jetpack.com/support/responsive-videos/
	 */
	function itcode_jetpack_setup() {
		// Add theme support for Infinite Scroll.
		add_theme_support( 'infinite-scroll', array(
			'container' => 'main',
			'render'    => 'itcode_infinite_scroll_render',
			'footer'    => 'wrapper-footer',
		) );
		// Add theme support for Responsive Videos.
		add_theme_support( 'jetpack-responsive-videos' );

	// Add theme support for Social Menus
	add_theme_support( 'jetpack-social-menu' );

	// Add theme support for JetPack Portfolio
	add_theme_support( 'jetpack-portfolio' );

	// Add theme support for testimonials
	add_theme_support( 'jetpack-testimonial' );

        add_theme_support( 'featured-content', array(
		'filter'	 => 'it_code_get_featured_posts',
		'max_posts'  => 20,
		'post_types' => array( 'post', 'page' ),
	) );
} // end function itcode_jetpack_setup
}
add_action( 'after_setup_theme', 'itcode_jetpack_setup' );

if ( ! function_exists( 'itcode_infinite_scroll_render' ) ) {
	/**
	 * Custom render function for Infinite Scroll.
	 */
	function itcode_infinite_scroll_render() {
		while ( have_posts() ) {
			the_post();
			if ( is_search() ) :
				get_template_part( 'loop-templates/content', 'search' );
			else :
				get_template_part( 'template-parts/content', get_post_format() ); 
//get_template_part( 'loop-templates/content', get_post_format() );
			endif;
		}
	}
} // end function itcode_infinite_scroll_render


function it_code_social_menu() {
	if ( ! function_exists( 'jetpack_social_menu' ) ) {
		return;
	} else {
		jetpack_social_menu();
	}
}


/**
 * Featured Posts
 */
function it_code_has_multiple_featured_posts() {
	$featured_posts = apply_filters( 'it_code_get_featured_posts', array() );
	if ( is_array( $featured_posts ) && 1 < count( $featured_posts ) ) {
		return true;
	}
	return false;
}
function it_code_get_featured_posts() {
	return apply_filters( 'it_code_get_featured_posts', false );
}

