<?php
/**
 * Theme basic setup.
 *
 * @package itcode
 */

require get_template_directory() . '/inc/theme-settings.php';

// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'itcode_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function itcode_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on itcode, use a find and replace
		 * to change 'itcode' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'itcode', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */

        
        add_image_size( 'itcode-featured-image', 2000, 1200, true );

        add_image_size( 'itcode-thumbnail-avatar', 100, 100, true );

        add_image_size( 'itcode-thumbnail-slide', 120, 240, true );


        // This theme uses wp_nav_menu() in location.
		register_nav_menus( array(
		    'primary' => __( 'Primary Menu', 'itcode' ),
                    'footer-menu' => esc_html__( 'Footer Menu', 'itcode' ),
                    'header-top-menu' => esc_html__( 'Topbar Menu', 'itcode' ),
                    'social' => __( 'Social Links Menu', 'itcode' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		/*
		 * Adding Thumbnail basic support
		 */
		add_theme_support( 'post-thumbnails' );

		/*
		 * Adding support for Widget edit icons in customizer
		 * Add theme support for selective refresh for widgets.
		 */
		add_theme_support( 'customize-selective-refresh-widgets' );

		/*
		 * Enable support for Post Formats.
		 * See http://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
                        'gallery',
                        'audio',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'itcode_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Set up the Wordpress Theme logo feature.
		add_theme_support( 'custom-logo', array(
                    'width'       => 250,
                     'height'      => 250,
                     'flex-width'  => true,
                ) );

        /**
         * This theme styles the visual editor to resemble the theme style,
         * specifically font, colors, and column width.
         */
        //add_editor_style( array( 'assets/css/editor-style.css', itcode_fonts_url() ) ); // todo do need?


        // Apply filter do_shortcode
        add_filter( 'itcode_do_shortcode', 'do_shortcode' );
        add_filter( 'widget_text', 'do_shortcode' );
        add_filter( 'widget_content', 'do_shortcode' );
        add_filter( 'header_customize_custom_text', 'do_shortcode' );





		// Check and setup theme default settings.
		setup_theme_default_settings();
	}
endif; // itcode_setup.
add_action( 'after_setup_theme', 'itcode_setup' );


if ( ! function_exists( 'woocommerce_support' ) ) {
    /**
     * Declares WooCommerce theme support.
     */
    function woocommerce_support() {
        add_theme_support( 'woocommerce' );
        // hook in and customizer form fields.
        add_filter( 'woocommerce_form_field_args', 'wc_form_field_args', 10, 3 );
    }
}
add_action( 'after_setup_theme', 'woocommerce_support' );


/**
 * Filter hook function monkey patching form classes
 * Author: Adriano Monecchi http://stackoverflow.com/a/36724593/307826
 *
 * @param string $args Form attributes.
 * @param string $key Not in use.
 * @param null   $value Not in use.
 *
 * @return mixed
 */
function wc_form_field_args( $args, $key, $value = null ) {

    // Start field type switch case.
    switch ( $args['type'] ) {

        /* Targets all select input type elements, except the country and state select input types */
        case 'select' :
            // Add a class to the field's html element wrapper - woocommerce
            // input types (fields) are often wrapped within a <p></p> tag.
            $args['class'][] = 'form-group';
            // Add a class to the form input itself.
            $args['input_class']       = array( 'form-control', 'input-lg' );
            $args['label_class']       = array( 'control-label' );
            $args['custom_attributes'] = array(
                'data-plugin'      => 'select2',
                'data-allow-clear' => 'true',
                'aria-hidden'      => 'true',
                // Add custom data attributes to the form input itself.
            );
            break;

        // By default WooCommerce will populate a select with the country names - $args
        // defined for this specific input type targets only the country select element.
        case 'country' :
            $args['class'][]     = 'form-group single-country';
            $args['label_class'] = array( 'control-label' );
            break;

        // By default WooCommerce will populate a select with state names - $args defined
        // for this specific input type targets only the country select element.
        case 'state' :
            // Add class to the field's html element wrapper.
            $args['class'][] = 'form-group';
            // add class to the form input itself.
            $args['input_class']       = array( '', 'input-lg' );
            $args['label_class']       = array( 'control-label' );
            $args['custom_attributes'] = array(
                'data-plugin'      => 'select2',
                'data-allow-clear' => 'true',
                'aria-hidden'      => 'true',
            );
            break;

        case 'password' :
        case 'text' :
        case 'email' :
        case 'tel' :
        case 'number' :
            $args['class'][]     = 'form-group';
            $args['input_class'] = array( 'form-control', 'input-lg' );
            $args['label_class'] = array( 'control-label' );
            break;

        case 'textarea' :
            $args['input_class'] = array( 'form-control', 'input-lg' );
            $args['label_class'] = array( 'control-label' );
            break;

        case 'checkbox' :
            $args['label_class'] = array( 'custom-control custom-checkbox' );
            $args['input_class'] = array( 'custom-control-input', 'input-lg' );
            break;

        case 'radio' :
            $args['label_class'] = array( 'custom-control custom-radio' );
            $args['input_class'] = array( 'custom-control-input', 'input-lg' );
            break;

        default :
            $args['class'][]     = 'form-group';
            $args['input_class'] = array( 'form-control', 'input-lg' );
            $args['label_class'] = array( 'control-label' );
            break;
    } // end switch ($args).

    return $args;
}

//if ( ! function_exists( 'custom_excerpt_more' ) ) {
//	/**
//	 * Removes the ... from the excerpt read more link
//	 *
//	 * @param string $more The excerpt.
//	 *
//	 * @return string
//	 */
//	function custom_excerpt_more( $more ) {
//		return '';
//	}
//}
//add_filter( 'excerpt_more', 'custom_excerpt_more' );
//
//if ( ! function_exists( 'all_excerpts_get_more_link' ) ) {
//	/**
//	 * Adds a custom read more link to all excerpts, manually or automatically generated
//	 *
//	 * @param string $post_excerpt Posts's excerpt.
//	 *
//	 * @return string
//	 */
//	function all_excerpts_get_more_link( $post_excerpt ) {
//
//		return $post_excerpt . ' [...]<p><a class="btn btn-secondary itcode-read-more-link" href="' . get_permalink( get_the_ID() ) . '">' . __( 'Read More...+',
//		'itcode' ) . '</a></p>';
//	}
//}
//add_filter( 'wp_trim_excerpt', 'all_excerpts_get_more_link' );
