<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package itcode
 */

if ( ! function_exists( 'itcode_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function itcode_posted_on() {

	// Get the author name; wrap it in a link.
	$byline = sprintf(
		/* translators: %s: post author */
		__( 'by %s', 'itcode' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . get_the_author() . '</a></span>'
	);

	// Finally, let's write all of this to the page.
	echo '<span class="posted-on">' . itcode_time_link() . '</span><span class="byline"> ' . $byline . '</span>';
}
endif;




if ( ! function_exists( 'itcode_time_link' ) ) :
/**
 * Gets a nicely formatted string for the published date.
 */
function itcode_time_link() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>, <time class="updated" datetime="%3$s">' . __( ' Edited %4$s', 'itcode' ) . '</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	// Wrap the time string in a link, and preface it with 'Posted on'.
	return sprintf(
		/* translators: %s: post date */
		__( '<span class="screen-reader-text">Posted on</span> %s', 'itcode' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
}
endif;

if ( ! function_exists( 'itcode_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function itcode_entry_footer() {
	// Hide category and tag text for pages.
        /* translators: used between list items, there is a space after the comma */

	$separate_meta = __( ', ', 'itcode' );

	// Get Categories for posts.
	$categories_list = get_the_category_list( $separate_meta );

	// Get Tags for posts.
	$tags_list = get_the_tag_list( '', $separate_meta );

	// We don't want to output .entry-footer if it will be empty, so make sure its not.
	if ( ( ( itcode_categorized_blog() && $categories_list ) || $tags_list ) || get_edit_post_link() ) {

		echo '<footer class="entry-footer my-4">';

	if ( 'post' === get_post_type() ) {
				if ( ( $categories_list && itcode_categorized_blog() ) || $tags_list ) {
					echo '<span class="cat-tags-links">';

						// Make sure there's more than one category before displaying.
		if ( $categories_list && itcode_categorized_blog() ) {
							echo '<span class="cat-links"><i class="fa fa-folder-open"></i> <span class="screen-reader-text">' . __( 'Categories', 'itcode' ) . '</span>' . $categories_list . '</span>';
		}

		if ( $tags_list ) {
							echo '<span class="tags-links"><i class="fa fa-hashtag"></i> <span class="screen-reader-text">' . __( 'Tags', 'itcode' ) . '</span>' . $tags_list . '</span>';
	}

		echo '</span>';
	}
		}

        if (get_theme_mod('show_edit_link', false ) == true){
            itcode_edit_link();
	}

		echo '</footer> <!-- .entry-footer -->';
	}
}
endif;



/**
 * Display a front page section.
 *
 * @param $partial WP_Customize_Partial Partial associated with a selective refresh request.
 * @param $id integer Front page section to display.
 */
if ( ! function_exists( 'itcode_front_page_section' ) ){

    function itcode_front_page_section( $partial = null, $id = 0 ) {
        if ( is_a( $partial, 'WP_Customize_Partial' ) ) {
            // Find out the id and set it up during a selective refresh.
            global $itcodecounter;
            $id = str_replace( 'panel_', '', $partial->id );
            $itcodecounter = $id;
        }

        global $post; // Modify the global post object before setting up post data.
        if ( get_theme_mod( 'panel_' . $id ) ) {
            global $post;
            $post = get_post( get_theme_mod( 'panel_' . $id ) );
            setup_postdata( $post );
            set_query_var( 'panel', $id );

            get_template_part( 'template-parts/page/content', 'front-page-panels' );

            wp_reset_postdata();
        } elseif ( is_customize_preview() ) {
            // The output placeholder anchor.
            echo '<article class="panel-placeholder panel itcode-panel itcode-panel' . $id . '" id="panel' . $id . '"><span class="itcode-panel-title">' . sprintf( __( 'Front Page Section %1$s Placeholder', 'itcode' ), $id ) . '</span></article>';
        }
    }
}

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
if ( ! function_exists( 'itcode_categorized_blog' ) ) {
    function itcode_categorized_blog() {
	$category_count = get_transient( 'itcode_categories' );

	if ( false === $category_count ) {
		// Create an array of all the categories that are attached to posts.
		$categories = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$category_count = count( $categories );

		set_transient( 'itcode_categories', $category_count );
	}

	return $category_count > 1;
}
}

/**
 * Flush out the transients used in itcode_categorized_blog.
 */
if ( ! function_exists( 'itcode_category_transient_flusher' ) ) {
    function itcode_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'itcode_categories' );
    }
    add_action( 'edit_category', 'itcode_category_transient_flusher' );
    add_action( 'save_post',     'itcode_category_transient_flusher' );
}

/**
 * Display navigation to next/previous post when applicable.
 */
if ( ! function_exists( 'itcode_post_nav' ) ) :

	function itcode_post_nav() {
		// Don't print empty markup if there's nowhere to navigate.
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous ) {
			return;
		}
		?>

		<div class="card">
			<div class="col-md-12">
				<nav class="navigation post-navigation my-2">
					<h2 class="sr-only"><?php _e( 'Post navigation', 'itcode' ); ?></h2>
					<div class="nav-links">
						<?php

							if ( get_previous_post_link() ) {
								previous_post_link( '<span class="nav-previous float-xs-left">%link</span>', _x( '<i class="fa fa-angle-left"></i>&nbsp;%title', 'Previous post link', 'itcode' ) );
							}
							if ( get_next_post_link() ) {
								next_post_link( '<span class="nav-next float-xs-right">%link</span>',     _x( '%title&nbsp;<i class="fa fa-angle-right"></i>', 'Next post link', 'itcode' ) );
							}
						?>
					</div><!-- .nav-links -->
				</nav><!-- .navigation -->
			</div>
		</div>
		<?php
	}
endif;
