<?php
/*---------------------------------------------------
/* COMMENT FIELDS
/*---------------------------------------------------*/
if ( !function_exists( 'itcode_comment_fields' ) ) {
	function itcode_comment_fields( $fields ) {

		$commenter = wp_get_current_commenter();
		$req       = get_option( 'require_name_email' );
		$aria_req  = ( $req ? " aria-required='true'" : '' );
		$html5     = current_theme_supports( 'html5', 'comment-form' ) ? 'html5' : 'xhtml';;

		$fields = array(
			'author' => '<div class="form-group col-md-6">' .
				'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" placeholder="' . esc_html__( 'Name*', 'itcode' ) . '" ' . $aria_req . '>' .
				'</div>',
			'email'  => '<div class="form-group col-md-6">' .
				'<input id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_email'] ) . '" placeholder="' . esc_html__( 'Email*', 'itcode' ) . '" ' . $aria_req . '>' .
				'</div>'
		);

		return $fields;

	}

	add_filter( 'itcode_comment_fields', 'itcode_comment_fields' );
}

/*---------------------------------------------------
/* COMMENT FORMS ARGS
/*---------------------------------------------------*/
if ( !function_exists( 'itcode_comment_form_args' ) ) {
	function itcode_comment_form_args( $comment_form_args ) {
		$commenter = wp_get_current_commenter();
		$req       = get_option( 'require_name_email' );
		$aria_req  = ( $req ? " aria-required='true'" : '' );
		$html5     = current_theme_supports( 'html5', 'comment-form' ) ? 'html5' : 'xhtml';;

		$comment_form_args['comment_field'] = '<div class="form-group col-md-12">' .
			'<textarea rows="6" id="comment" name="comment"  value="' . esc_attr( $commenter['comment_author_url'] ) . '" placeholder="' . esc_html__( 'Message', 'itcode' ) . '" ' . $aria_req . '></textarea>' .
			'</div>';

		$comment_form_args['class_submit'] = 'itcode-button style1 size-md';
		$comment_form_args['label_submit'] = esc_html__( 'SEND MESSAGE', 'itcode' );

		return $comment_form_args;
	}

	add_filter( 'itcode_comment_form_args', 'itcode_comment_form_args' );
}

/*---------------------------------------------------
/* SET ONE PAGE MENU
/*---------------------------------------------------*/
if ( !function_exists( 'itcode_main_menu_one_page_filter' ) ) {
	function itcode_main_menu_one_page_filter( $args ) {
		if ( isset( $args['theme_location'] ) && ( $args['theme_location'] != 'primary' ) ) {
			return $args;
		}
		$is_one_page = rwmb_meta( 'itcode_is_one_page' );
		if ( $is_one_page == '1' ) {
			$args['menu_class'] .= ' menu-one-page';
		}

		return $args;
	}

	add_filter( 'wp_nav_menu_args', 'itcode_main_menu_one_page_filter', 20 );
}

/*---------------------------------------------------
/* HEADER CUSTOMIZE
/*---------------------------------------------------*/
if ( !function_exists( 'itcode_header_customize_filter' ) ) {
	add_filter( 'itcode_header_customize_filter', 'itcode_header_customize_filter' );
	function itcode_header_customize_filter( $args ) {

		$enable_header_customize = rwmb_meta( 'itcode_enable_header_customize' );

		$header_customize = array();
		if ( $enable_header_customize == '1' ) {
			$page_header_customize = rwmb_meta( 'itcode_header_customize' );
			if ( isset( $page_header_customize['enable'] ) && !empty( $page_header_customize['enable'] ) ) {
				$header_customize = explode( '||', $page_header_customize['enable'] );
			}
		} else {
			if ( !empty( get_itcode_options('header_customize') ) && !empty( get_itcode_options('header_customize','enabled') ) && is_array( get_itcode_options('header_customize','enabled') ) ) {
				foreach ( get_itcode_options('header_customize','enabled') as $key => $value ) {
					$header_customize[] = $key;
				}
			}
		}

		ob_start();
		if ( count( $header_customize ) > 0 ) {
			?>
			<div class="header-customize">
				<?php foreach ( $header_customize as $key ) {
					switch ( $key ) {
						case 'search':
                            get_template_part( 'template-parts/header/search-button' );
							break;
						case 'shopping-cart':
							if ( class_exists( 'WooCommerce' ) ) {
                                get_template_part( 'template-parts/header/mini-cart' );
							}
							break;
						case 'get-a-quote':
                            get_template_part( 'template-parts/header/get-a-quote' );
							break;
						case 'custom-text':
                            get_template_part( 'template-parts/header/custom-text' );
							break;
					}
				} ?>
			</div>
			<?php
		}

		return ob_get_clean();
	}
}

/*---------------------------------------------------
/* AFTER MAIN MENU (for header 3)
/*---------------------------------------------------*/
if ( !function_exists( 'itcode_after_main_menu_filter' ) ) {
	add_filter( 'itcode_after_main_menu_filter', 'itcode_after_main_menu_filter' );
	function itcode_after_main_menu_filter( $args ) {
		$main_menu_after_customize = !empty( get_itcode_options('main_menu_after_customize') ) ?
			get_itcode_options('main_menu_after_customize') : '';
		ob_start();
		if ( !empty( $main_menu_after_customize ) ):
			$main_menu_after_customize = apply_filters( 'itcode_do_shortcode', $main_menu_after_customize );
			?>
			<div class="main-menu-custom-text">
				<?php echo wp_kses_post( $main_menu_after_customize ); ?>
			</div>
			<?php
		endif;

		return ob_get_clean();
	}
}

/**
 * CUSTOM TOGGLE TOP AREA
 */
if ( !function_exists( 'itcode_dynamic_sidebar_params' ) ) {
	function itcode_dynamic_sidebar_params( $params ) {
		global $itcode_toggle_top_widget_count;
		if ( !isset( $itcode_toggle_top_widget_count ) ) {
			$itcode_toggle_top_widget_count = 0;
		}
		$toggle_top_sidebar = get_itcode_options('toggle_top_sidebar');
		$toggle_top_layout  = get_itcode_options('toggle_top_layout');

		$widget_class = '';

		$widget_setting = array(
			'toggle-top-1' => array( 'itcode-col-3', 'itcode-col-3', 'itcode-col-3', 'itcode-col-3' ),
			'toggle-top-2' => array( 'itcode-col-6', 'itcode-col-3', 'itcode-col-3' ),
			'toggle-top-3' => array( 'itcode-col-3', 'itcode-col-3', 'itcode-col-6' ),
			'toggle-top-4' => array( 'itcode-col-6', 'itcode-col-6' ),
			'toggle-top-5' => array( 'itcode-col-4', 'itcode-col-4', 'itcode-col-4' ),
			'toggle-top-6' => array( 'itcode-col-8', 'itcode-col-4' ),
			'toggle-top-7' => array( 'itcode-col-4', 'itcode-col-8' ),
			'toggle-top-8' => array( 'itcode-col-3', 'itcode-col-6', 'itcode-col-3' ),
			'toggle-top-9' => array( 'itcode-col-12' ),
		);

		if ( isset( $widget_setting[$toggle_top_layout] ) ) {
			$widget_class = $widget_setting[$toggle_top_layout][$itcode_toggle_top_widget_count % count( $widget_setting[$toggle_top_layout] )];
		}
		$itcode_toggle_top_widget_count += 1;

		foreach ( $params as $key => $value ) {
			if ( isset( $value['id'] ) ) {
				if ( $value['id'] == $toggle_top_sidebar ) {
					$params[$key]['before_widget'] = str_replace( ' class="', ' class="' . esc_attr( $widget_class ) . ' ', $params[$key]['before_widget'] );
				}
			}
		}

		return $params;
	}

	add_filter( 'dynamic_sidebar_params', 'itcode_dynamic_sidebar_params' );
}
/**
 * ADD SEARCH FORM TO BEFORE MENU
 */
if ( !function_exists( 'itcode_search_form_before_menu' ) ) {
	function itcode_search_form_before_menu( $params ) {
		ob_start();
		?>
		<li class="menu-fly-search">
			<form method="get" action="<?php echo esc_url( site_url() ); ?>">
				<input type="text" name="s" placeholder="<?php echo esc_html__( 'Search...', 'itcode' ); ?>">
				<button type="submit"><i class="fa fa-search"></i></button>
			</form>
		</li>
		<?php
		$params .= ob_get_clean();

		return $params;
	}

	add_filter( 'menu_filter_before', 'itcode_search_form_before_menu', 10 );
}

