<?php
/**
 * Declaring widgets
 *
 * @package itcode
 */

/**
 * Count number of widgets in a sidebar
 * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
 */
function slbd_count_widgets( $sidebar_id ) {
	// If loading from front page, consult $_wp_sidebars_widgets rather than options
	// to see if wp_convert_widget_settings() has made manipulations in memory.
	global $_wp_sidebars_widgets;
	if ( empty( $_wp_sidebars_widgets ) ) :
		$_wp_sidebars_widgets = get_option( 'sidebars_widgets', array() );
	endif;
	
	$sidebars_widgets_count = $_wp_sidebars_widgets;
	
	if ( isset( $sidebars_widgets_count[ $sidebar_id ] ) ) :
		$widget_count = count( $sidebars_widgets_count[ $sidebar_id ] );
		$widget_classes = 'widget-count-' . count( $sidebars_widgets_count[ $sidebar_id ] );
		if ( $widget_count % 4 == 0 || $widget_count > 6 ) :
			// Four widgets er row if there are exactly four or more than six
			$widget_classes .= ' col-md-3';
		elseif ( 6 == $widget_count ) :
			// If two widgets are published
			$widget_classes .= ' col-md-2';
		elseif ( $widget_count >= 3 ) :
			// Three widgets per row if there's three or more widgets 
			$widget_classes .= ' col-md-4';
		elseif ( 2 == $widget_count ) :
			// If two widgets are published
			$widget_classes .= ' col-md-6';
		elseif ( 1 == $widget_count ) :
			// If just on widget is active
			$widget_classes .= ' col-md-12';
		endif; 
		return $widget_classes;
	endif;
}

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
if ( ! function_exists( 'itcode_widgets_init' ) ) {
	/**
	 * Initializes themes widgets.
	 */
	function itcode_widgets_init() {
        /*register_sidebar( array(
            'name'          => __( 'Right Sidebar', 'itcode' ),
            'id'            => 'right-sidebar',
            'description'   => 'Right sidebar widget area',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        ) );*/

        /*register_sidebar( array(
            'name'          => __( 'Left Sidebar', 'itcode' ),
            'id'            => 'left-sidebar',
            'description'   => 'Left sidebar widget area',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        ) );*/

        register_sidebar( array(
            'name'          => esc_html__( "Toggle Top", 'itcode' ),
            'id'            => 'toggle_top_sidebar',
            'description'   => esc_html__( "Toggle Top", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        register_sidebar( array(
            'name'          => esc_html__( "Top Bar Left", 'itcode' ),
            'id'            => 'top_bar_left',
            'description'   => esc_html__( "Top Bar Left", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        register_sidebar( array(
            'name'          => esc_html__( "Top Bar Right", 'itcode' ),
            'id'            => 'top_bar_right',
            'description'   => esc_html__( "Top Bar Right", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        register_sidebar( array(
            'name'          => __( 'Hero Slider', 'itcode' ),
            'id'            => 'hero',
            'description'   => 'Hero slider area. Place two or more widgets here and they will slide!',
            'before_widget' => '<div class="carousel-item">',
            'after_widget'  => '</div>',
            'before_title'  => '',
            'after_title'   => '',
        ) );

        register_sidebar( array(
            'name'          => __( 'Hero Static', 'itcode' ),
            'id'            => 'statichero',
            'description'   => 'Static Hero widget. no slider functionallity',
            'before_widget'  => '<div id="%1$s" class="static-hero-widget %2$s '. slbd_count_widgets( 'statichero' ) .'">',
            'after_widget'   => '</div><!-- .static-hero-widget -->',
            'before_title'   => '<h3 class="widget-title">',
            'after_title'    => '</h3>',
        ) );

        register_sidebar( array(
            'name'          => esc_html__( "Sidebar 1", 'itcode' ),
            'id'            => 'sidebar-1',
            'description'   => esc_html__( "Widget Area 1", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        register_sidebar( array(
            'name'          => esc_html__( "Sidebar 2", 'itcode' ),
            'id'            => 'sidebar-2',
            'description'   => esc_html__( "Widget Area 2", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        register_sidebar( array(
            'name'          => __( 'Footer Full', 'itcode' ),
            'id'            => 'footerfull',
            'description'   => 'Widget area below main content and above footer',
            'before_widget'  => '<div id="%1$s" class="footer-widget %2$s '. slbd_count_widgets( 'footerfull' ) .'">',
            'after_widget'   => '</div><!-- .footer-widget -->',
            'before_title'   => '<h4 class="widget-title">',
            'after_title'    => '</h4>',
        ) );

        register_sidebar( array(
            'name'          => esc_html__( "Footer Above", 'itcode' ),
            'id'            => 'footer-above',
            'description'   => esc_html__( "Footer above", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        register_sidebar( array(
            'name'          => __( 'Footer 1', 'itcode' ),
            'id'            => 'footer-1',
            'description'   => __( 'Add widgets here to appear in your footer.', 'itcode' ),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget'  => '</section>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>',
        ) );

        register_sidebar( array(
            'name'          => __( 'Footer 2', 'itcode' ),
            'id'            => 'footer-2',
            'description'   => __( 'Add widgets here to appear in your footer.', 'itcode' ),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget'  => '</section>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>',
        ) );

        register_sidebar( array(
            'name'          => esc_html__( "Footer 3", 'itcode' ),
            'id'            => 'footer-3',
            'description'   => __( 'Add widgets here to appear in your footer.', 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        register_sidebar( array(
            'name'          => esc_html__( "Footer 4", 'itcode' ),
            'id'            => 'footer-4',
            'description'   => __( 'Add widgets here to appear in your footer.', 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        register_sidebar( array(
            'name'          => esc_html__( 'Woocommerce', 'itcode' ),
            'id'            => 'woocommerce',
            'description'   => esc_html__( 'Woocommerce', 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );

        /*register_sidebar( array(
            'name'          => esc_html__( "Portfolito", 'itcode' ),
            'id'            => 'portfolio',
            'description'   => esc_html__( "Portfolito Sidebar", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );*/

        /*register_sidebar( array(
            'name'          => esc_html__( "Sidebar Page", 'itcode' ),
            'id'            => 'sidebar-page',
            'description'   => esc_html__( "Page Sidebar", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );*/

        /*register_sidebar( array(
            'name'          => esc_html__( "Sidebar Services", 'itcode' ),
            'id'            => 'sidebar-services',
            'description'   => esc_html__( "Page Services", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );*/

        /*register_sidebar( array(
            'name'          => esc_html__( "Sidebar Bottom Services", 'itcode' ),
            'id'            => 'sidebar-services-bottom',
            'description'   => esc_html__( "Page Bottom Services", 'itcode' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );*/

	}
} // endif function_exists( 'itcode_widgets_init' ).
add_action( 'widgets_init', 'itcode_widgets_init' );

