<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $woocommerce_loop, $itcode_woocommerce_loop;


$itcode_loop = itcode_loop(); // global return var  itcode_loop

$itcode_loop['layout_style'] = isset( $_GET['layout'] ) ? $_GET['layout'] : get_theme_mod( 'archive_product_layout', 'container' );

$itcode_loop['sidebar']  = isset( $_GET['sidebar'] ) ? $_GET['sidebar'] : get_theme_mod( 'archive_product_sidebar', 'right' );

$itcode_loop['paging_style']  = isset( $_GET['paging'] ) ? $_GET['paging'] : get_theme_mod('archive_paging_style', 'default');

$itcode_loop['sidebar_width'] = isset( $_GET['sidebar_width'] ) ? $_GET['sidebar_width'] : get_theme_mod('archive_product_sidebar_width', 'small');


$itcode_loop['left_sidebar'] = get_theme_mod('archive_product_left_sidebar' , 'woocommerce');
$itcode_loop['right_sidebar'] =get_theme_mod('archive_product_right_sidebar' , 'woocommerce');

$itcode_loop['image-size'] = 'blog-classic';

$itcode_loop['sidebar_col'] = 'col-md-3';
if ( $itcode_loop['sidebar_width'] == 'large' ) {
    $itcode_loop['sidebar_col'] = 'col-md-4';
}

// bootstrap grid
$itcode_loop['content_col_number'] = 12;
if ( is_active_sidebar( $itcode_loop['left_sidebar'] ) && ( ( $itcode_loop['sidebar'] == 'both' ) || ( $itcode_loop['sidebar'] == 'left' ) ) ) {
    if ( $itcode_loop['sidebar_width'] == 'large' ) {
        $itcode_loop['content_col_number'] -= 4;
    } else {
        $itcode_loop['content_col_number'] -= 3;
    }
    $itcode_loop['image-size'] = 'blog-classic-sidebar';
}
if ( is_active_sidebar( $itcode_loop['right_sidebar'] ) && ( ( $itcode_loop['sidebar'] == 'both' ) || ( $itcode_loop['sidebar'] == 'right' ) ) ) {
    if ( $itcode_loop['sidebar_width'] == 'large' ) {
        $itcode_loop['content_col_number'] -= 4;
    } else {
        $itcode_loop['content_col_number'] -= 3;
    }
    $itcode_loop['image-size'] = 'blog-classic-sidebar';
}

$itcode_loop['content_col'] = 'col-md-' . $itcode_loop['content_col_number'];
if ( ( $itcode_loop['content_col_number'] == 12 ) && ( $itcode_loop['layout_style'] == 'full' ) ) {
    $itcode_loop['content_col'] = '';
}

$itcode_loop['wrapper_id']= 'archive-wrapper';

$itcode_loop['main_class'][] = 'site-content-page';

if ( $itcode_loop['content_col_number'] < 12 ) {
    $itcode_loop['main_class'][] = 'has-sidebar';
}


$itcode_loop['type'] = 'product-archive' ;

////////////////




$archive_display_columns = 3;
$archive_display_columns = isset( $_GET['columns'] ) ? $_GET['columns'] : '';
if ( !in_array( $archive_display_columns, array( '2', '3', '4', '5', '6' ) ) ) {
	$archive_display_columns = get_theme_mod('product_display_columns', '2');
}

$itcode_woocommerce_loop['columns'] = $archive_display_columns;
$sidebar_col                        = 'col-md-3';
if ( $itcode_loop['sidebar_width'] == 'large' ) {
	$sidebar_col = 'col-md-4';
}

$content_col_number = 12;

if ( is_active_sidebar( $itcode_loop['left_sidebar'] ) && ( ( $itcode_loop['sidebar'] == 'both' ) || ( $itcode_loop['sidebar'] == 'left' ) ) ) {
	if ( $itcode_loop['sidebar_width'] == 'large' ) {
		$content_col_number -= 4;
	} else {
		$content_col_number -= 3;
	}
}
if ( is_active_sidebar( $itcode_loop['right_sidebar'] ) && ( ( $itcode_loop['sidebar'] == 'both' ) || ( $itcode_loop['sidebar'] == 'right' ) ) ) {
	if ( $itcode_loop['sidebar_width'] == 'large' ) {
		$content_col_number -= 4;
	} else {
		$content_col_number -= 3;
	}
}

$content_col = 'col-md-' . $content_col_number;
if ( ( $content_col_number == 12 ) && ( $itcode_loop['layout_style'] == 'full' ) ) {
	$content_col = '';
}

$product_show_result_count     = get_itcode_options('product_show_result_count');
$product_show_catalog_ordering = get_itcode_options('product_show_catalog_ordering');

$archive_class = array( 'archive-product-wrap', 'clearfix' );


if ( ( $product_show_result_count == 0 ) && ( $product_show_catalog_ordering == 0 ) ) {
	$archive_class[] = 'catalog-filter-visible';
} else {
	if ( $product_show_result_count == 0 ) {
		$archive_class[] = 'result-count-visible';
	}

	if ( $product_show_catalog_ordering == 0 ) {
		$archive_class[] = 'catalog-ordering-visible';
	}
}


$archive_class[] = 'layout-' . $itcode_loop['layout_style'];


// start list grid


$design = 1 ; //(int) $smof_data->oxy_general_settings['oxy_shop_page_display_style']; // will related to admin panel. Temporarily set for development.

if (isset($_GET['itcode_page_layout']) && is_numeric($_GET['itcode_page_layout'])) {
    $design = $_GET['itcode_page_layout'];

    switch ($design) {
        case 1:
        case 2:
            $cols = 4;
            break;
        case 4:
            $cols = 3;
            break;
        default:
            $cols = 6;
            break;
    }
}


$leftbar = $rightbar = $main = '';

switch ($design) {
    case 1:
        $rightbar = 'hidesidebar';
        $main = 'large-9 medium-9 small-12';
        break;
    case 2:
        $leftbar = 'hidesidebar';
        $main = 'large-9 medium-9 small-12';
        break;

    case 4:
        $main = 'large-6 medium-9 small-12';
        break;

    default:
        $leftbar = $rightbar = 'hidesidebar';
        $main = 'large-12 medium-12';
        break;
}


$colclass = '';

if (!isset($cols))
    $cols = 4 ; //(int) $smof_data->oxy_general_settings['oxy_layout_pb_noc'];

switch ($cols) {
    case 3:
        $colclass = 'large-4 medium-4 small-6 columns';
        break;
    case 4:
        $colclass = 'col-md-3 columns';
        break;
    case 6:
        $colclass = 'large-2 medium-3 small-6 columns';
        break;
    default:
        $colclass = 'large-6 medium-6 small-6 columns';
        break;
}
// end list grid

get_header( 'shop' ); ?>

<?php
/**
 * itcode_archive_product_heading - 5
 **/
do_action( 'itcode_before_archive_product' );
?>



<!-- start list grid -->
<script type="text/javascript"><!--

    jQuery(function($) {

        "use strict";

        var colclass = '<?php echo esc_attr($colclass) ?>';

        var centered = '<?php
            /*if ($smof_data->oxy_general_settings['oxy_category_prod_align'] == 2) {
                echo 'centered';
            }*/
            ?>';

        $.display = function(view) {

            if (view == 'list') {

                $('.product-grid').attr('class', 'product-list');

                $('.product-list > ul > li').each(function(index, element) {

                    var element = $(this);

                    element.removeClass(colclass).addClass('col-12');

                    if (centered != '')
                        element.removeClass(centered);

//                    var htmls = '<div class="row">';
                    var htmls = '';

                    var image = element.find('.product-thumb').html();



                    htmls += '<div class="card product-item-wrap">';
                        htmls += '<div class="row">';

                            htmls += '<div class="col-3">';
                                if (image != undefined) {
                                    htmls += '<div class="product-thumb">' + image + '</div>';
                                }
                            htmls += '</div>';
                            htmls += '<div class="col-9">';
                                var block = element.find('div.card-block').html();
                                if (block != undefined) {
                                    htmls += '<div class="card-block product-info">' + block + '</div>';
                                }
                            htmls += '</div>';





                        //htmls += '<div class="card-header">';
                        //htmls += '</div>';

                        //htmls += '<div class="card-block">';
                            //
                        //    if (element.find('.name').length > 0)
                         //       htmls += '<div class="name">' + element.find('.name').html() + '</div>';

                            //
                        //    htmls += '  <div class="description">' + element.find('.description').html() + '</div>';
                        //htmls += '</div>';

                        //var rating = element.find('div.rating').html();

                        /*if (rating != undefined) {
                            htmls += '<div class="rating">' + rating + '</div>';
                        }
                        else {

                            if (element.find('div.star-rating').length > 0) {

                                var rating = element.find('div.star-rating').html();

                                var rattitle = element.find('div.star-rating').attr('title');

                                htmls += '<div class="star-rating" title="' + rattitle + '">' + rating + '</div>';
                            }
                        }*/


                        //html += '  <div class="wishlist">' + $(element).find('.wishlist').html() + '</div>';
                        //html += '  <div class="compare">' + $(element).find('.compare').html() + '</div>';

                    htmls += '</div>';
                    htmls += '</div>';



                    /*htmls += '<div class="large-3 medium-3 columns">';
                    var price = element.find('.price').html();

                    if (price != null) {
                        htmls += '<div class="price">' + price + '</div>';
                    }
                    htmls += '  <div class="cart">' + element.find('.cart').html() + '</div>';
                    htmls += '</div>';

                    //htmls += '</div>';
                    htmls += '</div>';*/

                    element.html(htmls);
                });


                $.cookie('display', 'list');

            } else {

                $('.product-list').attr('class', 'product-grid');

                $('.product-grid > ul > li').each(function(index, element) {
                    var html = '';

                    element = $(this);
                    //alert(colclass);
                    //element.removeClass('large-12 medium-12').addClass(colclass);

                    element.attr('class', colclass);
                    if (centered != '')
                        element.addClass(centered);


                    html += '<div class="card product-item-wrap">';

                        var element = $(this);

                        var image = element.find('.product-thumb').html();

                        if (image != undefined) {

                            html += '<div class="product-thumb">' + image + '</div>';
                        }

                        //html += '<div class="card-block">';
                            //
                            //if (element.find('.card-block product-info').length > 0)
                                //html += '<div class="card-block product-info">' + element.find('.card-block product-info').html() + '</div>';
                            //
                            //html += '<div class="description">' + $(element).find('.description').html() + '</div>';
                        //html += '</div>';
                        var block = element.find('div.card-block').html();
                        if (block != undefined) {
                            html += '<div class="card-block product-info">' + block + '</div>';
                        }




                    /*var image = element.find('.image').html();

                        if (image != undefined) {

                            html += '<div class="image">' + image + '</div>';
                        }*/


                        /*var rating = element.find('div.rating').html();

                        if (rating != undefined) {
                            html += '<div class="rating hidden-phone hidden-tablet">' + rating + '</div>';
                        }
                        if (element.find('.name').length > 0)
                            html += '<div class="name">' + element.find('.name').html() + '</div>';
                        if (element.find('.product_box_brand').length > 0)
                            html += '<div class="product_box_brand">' + element.find('.product_box_brand').html() + '</div>';

                        if (rating == undefined) {

                            if (element.find('div.star-rating').length > 0) {

                                var rating = element.find('div.star-rating').html();

                                var rattitle = element.find('div.star-rating').attr('title');

                                html += '<div class="star-rating" title="' + rattitle + '">' + rating + '</div>';
                            }
                        }
                        html += '<div class="description">' + $(element).find('.description').html() + '</div>';
                        var price = element.find('.price').html();*/

                    /*if (price != null) {
                        html += '<div class="price">' + price + '</div>';
                    }

                    html += '<div class="cart">' + element.find('.cart').html() + '</div>';
                    //html += '<div class="wishlist">' + $(element).find('.wishlist').html() + '</div>';
                    //html += '<div class="compare">' + $(element).find('.compare').html() + '</div>';
                    html += '</div>';*/

                    element.html(html);
                });


                $.cookie('display', 'grid');
            }
        }

        $('a.list-trigger').click(function() {
            $.display('list');
        });
        $('a.grid-trigger').click(function() {
            $.display('grid');
        });

        var view = '<?php echo esc_attr(get_theme_mod('view_style_list_grid', 'list' )) ?>';
        view = $.cookie('display') !== undefined ? $.cookie('display') : view;

        if (view) {
            $.display(view);
        } else {
            $.display('grid');
        }



    });
    //--></script>


<main class="wrapper site-content-archive-product">
	<?php if ( $itcode_loop['layout_style'] != 'full' ): ?>
	<div class="<?php echo esc_attr( $itcode_loop['layout_style'] ) ?> clearfix">
		<?php endif; ?>

		<?php if ( ( $content_col_number != 12 ) || ( $itcode_loop['layout_style'] != 'full' ) ): ?>
		<div class="row clearfix">
		<?php endif; ?>

			<?php if ( is_active_sidebar( $itcode_loop['left_sidebar'] ) && ( ( $itcode_loop['sidebar'] == 'left' ) || ( $itcode_loop['sidebar'] == 'both' ) ) ): ?>
				<div class="sidebar woocommerce-sidebar <?php echo esc_attr( $sidebar_col ) ?> hidden-sm hidden-xs">
					<?php dynamic_sidebar( $itcode_loop['left_sidebar'] ); ?>
				</div>
		<?php endif; ?>

			<div class="<?php echo esc_attr( $content_col ) ?>">
				<div class="<?php echo join( ' ', $archive_class ); ?>">
		<?php if ( have_posts() ) : ?>
						<div class="catalog-filter clearfix">
			<?php
				/**
                                 * woocommerce_before_shop_loop hook.
				 *
				 * @hooked woocommerce_result_count - 20
				 * @hooked woocommerce_catalog_ordering - 30
				 */
				do_action( 'woocommerce_before_shop_loop' );
			?>
						</div>

			<?php woocommerce_product_loop_start(); ?>

				<?php woocommerce_product_subcategories(); ?>


                            <div class="product-grid">

                                <ul class="products card-deck">

				<?php while ( have_posts() ) : the_post(); ?>

                                        <?php wc_get_template_part( 'content', 'product-list' ); ?>

				<?php endwhile; // end of the loop. ?>

                                </ul>

                            </div>


                                <?php /*while ( have_posts() ) : the_post(); */?><!--

                                    <?php /*wc_get_template_part( 'content', 'product' ); */?>

                                --><?php /*endwhile; // end of the loop. */?>


			<?php woocommerce_product_loop_end(); ?>

			<?php
				/**
                             * woocommerce_after_shop_loop hook.
				 *
				 * @hooked woocommerce_pagination - 10
				 */
				do_action( 'woocommerce_after_shop_loop' );
			?>

		<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

			<?php wc_get_template( 'loop/no-products-found.php' ); ?>

		<?php endif; ?>
				</div>
			</div>

			<?php if ( is_active_sidebar( $itcode_loop['right_sidebar'] ) && ( ( $itcode_loop['sidebar'] == 'right' ) || ( $itcode_loop['sidebar'] == 'both' ) ) ): ?>
				<div class="sidebar woocommerce-sidebar <?php echo esc_attr( $sidebar_col ) ?> hidden-sm hidden-xs">
					<?php dynamic_sidebar( $itcode_loop['right_sidebar'] ); ?>
				</div>
			<?php endif; ?>

			<?php if ( ( $content_col_number != 12 ) || ( $itcode_loop['layout_style'] != 'full' ) ): ?>
		</div>
	    <?php endif; ?>

		<?php if ( $itcode_loop['layout_style'] != 'full' ): ?>
	</div>
<?php endif; ?>
</main>
<?php get_footer( 'shop' ); ?>
