<?php
/**
 * Mini-cart
 *
 * Contains the markup for the mini-cart, used by the cart widget.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/mini-cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; 
} // Exit if accessed directly

$both_button = '';
if ( !empty( get_itcode_options('header_shopping_cart_button') )
	&& ( get_itcode_options('header_shopping_cart_button','view-cart') == '1' )
	&& ( get_itcode_options('header_shopping_cart_button','checkout') == '1' )
) {
	$both_button = 'both-buttons';
}
$ul_class = array();
if ( !isset( $args ) || !isset( $args['list_class'] ) ) {
	$ul_class[] = $args['list_class'] = '';
}
$ul_class[] = 'list-unstyled';
//list-unstyled
$cart_list_sub_class   = array();
$cart_list_sub_class[] = 'cart_list_wrapper';
if ( sizeof( WC()->cart->get_cart() ) > 0 ) {
	$cart_list_sub_class[] = 'has-cart';
}

////var_dump($cart_list_sub_class);// array(1) { [0]=> string(17) "cart_list_wrapper" }

// echo join( ' ', $cart_list_sub_class );

?>


<div class="widget_shopping_cart_icon">
    <a class="nav-cart" href="<?php echo esc_url( wc_get_cart_url() ); ?>" id="dropdown-nav-cart" >
        <span class="badge badge-pill badge-default"><i class="fa fa-shopping-cart"></i> <span><?php echo sizeof( WC()->cart->get_cart() ); ?></span></span>
    </a>
</div><!-- end icon -->

<div class="card <?php echo join( ' ', $cart_list_sub_class ); ?>">

    <?php if ( ! WC()->cart->is_empty() ) : ?>
    <div class="card-header">
        <div class="d-flex justify-content-center">
            <div class="p-1">
                <strong><?php _e( 'Subtotal', 'woocommerce' ); ?>:</strong> <span class="badge badge-pill badge-success"><?php echo WC()->cart->get_cart_subtotal(); ?></span>

            </div>
        </div>
    </div>
    <?php endif; ?>


<!-- start ul -->

    <?php do_action( 'woocommerce_before_mini_cart' ); ?>

    <ul class="cart_list product_list_widget list-group list-group-flush <?php echo join( ' ', $ul_class ); ?>">

        <?php if ( ! WC()->cart->is_empty() ) : ?>

            <?php
            foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                $_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                $product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                    $product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key );
                    $thumbnail         = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
                    $product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
                    $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                    ?>
                    <li class="list-group-item <?php echo esc_attr( apply_filters( 'woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key ) ); ?>">

                        <div class="d-flex flex-row">
                            <div class="col-5 d-inline-flex">
                                <?php if ( ! $_product->is_visible() ) : ?>
                                    <?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ) ; ?>
                                <?php else : ?>
                                    <a href="<?php echo esc_url( $product_permalink ); ?>">
                                        <?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ) ; ?>
                                    </a>
                                <?php endif; ?>
                            </div>
                            <div class="p-2">
                                <span><a class="p-1" href="<?php echo esc_url( $product_permalink ); ?>"><?php echo  $product_name ; ?></a></span>
                                <?php echo WC()->cart->get_item_data( $cart_item ); ?>

                                <?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . sprintf( '%s &times; %s', $cart_item['quantity'], $product_price ) . '</span>', $cart_item, $cart_item_key ); ?>

                            </div>
                            <div class="p-1 align-self-start">
                                <?php
                                echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
                                    '<a href="%s" class="button-empty" title="%s" data-product_id="%s" data-product_sku="%s"><i class="fa fa-trash-o"></i></a>',
                                    esc_url( WC()->cart->get_remove_url( $cart_item_key ) ),
                                    __( 'Remove this item', 'woocommerce' ),
                                    esc_attr( $product_id ),
                                    esc_attr( $_product->get_sku() )
                                ), $cart_item_key );
                                ?>
                            </div>
                        </div>

                    </li>
                    <?php
                }
            }
            ?>

        <?php else : ?>

            <li class="empty"><?php _e( 'No products in the cart.', 'woocommerce' ); ?></li>

        <?php endif; ?>

    </ul><!-- end product list -->



        <?php if ( ! WC()->cart->is_empty() ) : ?>
            <div class="card-footer">

                <?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>

                <div class="d-flex justify-content-center">


                    <div class="p-1">
                        <?php if (  get_theme_mod('header_shopping_cart_button_checkout', true ) == '1'  ){ ?>
                            <a href="<?php echo esc_url( wc_get_checkout_url() ); ?>" class="btn btn-sm btn-success btn-block checkout wc-forward" role="button"><i class="fa fa-check"></i> <?php _e( 'Checkout', 'itcode' ); ?></a>

                            <?php if (  get_theme_mod('header_shopping_cart_button_view-cart', true ) == '1' ) { ?>
                                <a href="<?php echo esc_url( wc_get_cart_url() ); ?>" class="btn btn-sm btn-primary btn-block wc-forward" role="button"><i class="fa fa-shopping-cart"></i> <?php _e( 'View Cart', 'itcode' ); ?></a>
                            <?php } ?>

                            <a class="btn btn-sm btn-outline-secondary btn-block" href="<?php echo esc_url( wc_get_cart_url() ); ?>?empty-cart" role="button"><i class="fa fa-trash-o"></i><?php echo esc_html__( 'Empty Cart', 'itcode' ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>


<?php do_action( 'woocommerce_after_mini_cart' ); ?>
</div> <!-- end card -->