<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author        WooThemes
 * @package       WooCommerce/Templates
 * @version 2.6.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product, $woocommerce_loop, $post;
// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
    return;
}
// Store loop count we're currently on
if ( empty( $woocommerce_loop['loop'] ) ){
	$woocommerce_loop['loop'] = 0;
}

// Store column count for displaying the grid
if ( empty( $woocommerce_loop['columns'] ) ){
	$woocommerce_loop['columns'] = apply_filters( 'loop_shop_columns', 4 );
}
// Ensure visibilty
if ( ! $product || ! $product->is_visible() ){
	return;
}
// Increase loop count
$woocommerce_loop['loop']++;

//$altimgclass = $smof_data['sellya_product_alt_image_setting'] != 0? ' havealtimg':'';

$colclass = 'columns ';
$cols = 4 ; //(int)$smof_data->oxy_general_settings['oxy_layout_pb_noc'];

if(is_product() || !is_shop() || !is_product_category() || !is_taxonomy('brands')){
    $cols = $woocommerce_loop['columns'];
}

switch ($cols){            
    case 3:        
        $colclass = 'large-4 medium-4 small-6';
        break;    
    case 4:        
        $colclass = 'col-3';
        break;
    case 6:        
        $colclass = 'large-2 medium-4 small-6';
        break;
    default:        
        $colclass = 'large-6 medium-4 small-6';
        break; 
}
if ( ( $woocommerce_loop['loop'] - 1 ) % $woocommerce_loop['columns'] == 0 )
{
        $colclass .= ' clearleft';
}
if(get_theme_mod('category_prod_align', 2 ) == 2){
    $colclass .= ' centered'; 
}


// Extra post classes
$classes        = array();
$classes[]      = 'card';
$classes[]      = 'product-item-wrap';
$product_rating = get_theme_mod('product_show_rating', false );
if ( $product_rating == true ) {
    $classes[] = 'rating-visible';
}

$add_to_cart_animation = get_theme_mod('add_to_cart_animation', false );
if ( $add_to_cart_animation == true ) {
    $classes[] = 'add-to-cart-animation-visible';
}
$product_quick_view = get_theme_mod('product_quick_view', false );
if ( $product_quick_view == true ) {
    $classes[] = 'quick-view-visible';
}
?>


<li class="<?php echo esc_attr($colclass)?>">
    <div <?php post_class( $classes ); ?>>
        <!-- start content-product card -->
            <!--<img class="card-img-top" src="..." alt="Card image cap">-->
            <div class="product-thumb">
                <?php
                /**
                 * woocommerce_before_shop_loop_item_title hook.
                 *
                 * @hooked woocommerce_show_product_loop_sale_flash - 10
                 * @hooked woocommerce_template_loop_product_thumbnail - 10
                 * @hooked itcode_woocomerce_template_loop_quick_view - 15
                 * @hooked itcode_woocomerce_template_loop_link - 20
                 */
                do_action( 'woocommerce_before_shop_loop_item_title' );

                add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
                remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 5 );
                do_action( 'woocommerce_after_shop_loop_item' );

                ?>
            </div><!-- end product-thumb -->
            <div class="card-block">
                <?php

                /**
                 * woocommerce_shop_loop_item_title hook.
                 *
                 * @hooked woocommerce_template_loop_product_title - 10
                 */
                //do_action( 'woocommerce_shop_loop_item_title' );

                /**
                 * woocommerce_after_shop_loop_item_title hook.
                 *
                 * @hooked itcode_woocommerce_template_loop_name - 1
                 * @hooked woocommerce_template_loop_rating - 5
                 * @hooked woocommerce_template_loop_price - 10
                 */
                do_action( 'woocommerce_after_shop_loop_item_title' );
                ?>

                <div class="product-add-to-cart">
                    <?php
                    /**
                     * woocommerce_after_shop_loop_item hook
                     *
                     * @hooked woocommerce_template_loop_price - 5
                     * @hooked woocommerce_template_loop_add_to_cart - 10
                     */
                    remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
                    add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 5 );
                    do_action( 'woocommerce_after_shop_loop_item' );
                    ?>
                </div>
            </div>

        </div><!-- end content-product -->
</li>