<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author        WooThemes
 * @package       WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product, $woocommerce_loop;
// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}


// Extra post classes
$classes        = array();
$classes[]      = 'card';
$classes[]      = 'product-item-wrap';
$product_rating = get_theme_mod('product_show_rating', false );
if ( $product_rating == true ) {
	$classes[] = 'rating-visible';
}

$add_to_cart_animation = get_theme_mod('add_to_cart_animation', false );
if ( $add_to_cart_animation == true ) {
	$classes[] = 'add-to-cart-animation-visible';
}
$product_quick_view = get_theme_mod('product_quick_view', false );
if ( $product_quick_view == true ) {
	$classes[] = 'quick-view-visible';
}

?>


<div <?php post_class( $classes ); ?>><!-- start content-product card -->
    <!--<img class="card-img-top" src="..." alt="Card image cap">-->

	<?php do_action( 'woocommerce_before_shop_loop_item' ); ?>
	<div class="product-item-inner">
    <div class="product-thumb">
        <?php
        /**
         * woocommerce_before_shop_loop_item_title hook.
         *
         * @hooked woocommerce_show_product_loop_sale_flash - 10
         * @hooked woocommerce_template_loop_product_thumbnail - 10
         * @hooked itcode_woocomerce_template_loop_quick_view - 15
         * @hooked itcode_woocomerce_template_loop_link - 20
         */
        do_action( 'woocommerce_before_shop_loop_item_title' );

        add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
        remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 5 );
        do_action( 'woocommerce_after_shop_loop_item' );

        ?>
    </div><!-- end product-thumb -->

    <div class="card-block product-info">
        <?php
        /**
         * woocommerce_after_shop_loop_item_title hook.
         *
         * @hooked itcode_woocommerce_template_loop_name - 1
         * @hooked woocommerce_template_loop_rating - 5
         */

        do_action( 'woocommerce_after_shop_loop_item_title' );
        ?>

        <div class="product-add-to-cart">
            <?php
            /**
             * woocommerce_after_shop_loop_item hook
             *
             * @hooked woocommerce_template_loop_price - 5
             * @hooked woocommerce_template_loop_add_to_cart - 10
             */
            remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
            add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 5 );
            do_action( 'woocommerce_after_shop_loop_item' );
            ?>
        </div>

		</div>
	</div>
</div><!-- end content-product -->