<?php
/**
 * Single Product Meta
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/meta.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author        WooThemes
 * @package       WooCommerce/Templates
 * @version     3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $post, $product;

$cat_count = sizeof( get_the_terms( $post->ID, 'product_cat' ) );
$tag_count = sizeof( get_the_terms( $post->ID, 'product_tag' ) );

$weight     = $product->get_weight();
$dimensions = $product->get_dimensions();

?>
<div class="product_meta">
	<?php do_action( 'woocommerce_product_meta_start' ); ?>
	<?php if ( wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>

		<span class="sku_wrapper"><label><?php echo esc_html__( 'SKU:', 'itcode' ); ?></label> <span class="sku" itemprop="sku"><?php echo ( $sku = $product->get_sku() ) ? $sku : esc_html__( 'N/A', 'itcode' ); ?></span>.</span>

	<?php endif; ?>

	<span class="product-stock-status-wrapper"><label><?php echo esc_html__( 'Availability:', 'itcode' ) ?></label> <span class="product-stock-status" itemprop="stock"><?php echo ( $product->is_in_stock() ) ? esc_html__( 'In Stock', 'itcode' ) : esc_html__( 'Out Of Stock', 'itcode' ); ?></span></span>

	<?php if ( !empty( $dimensions ) ) : ?>
		<span><label><?php echo esc_html__( "Size:", 'itcode' ); ?></label><span> <?php echo esc_html( $product->get_dimensions() ); ?></span></span>
	<?php endif; ?>

	<?php if ( !empty( $weight ) ) : ?>
		<span><label><?php echo esc_html__( "Shipping Weight:", 'itcode' ); ?></label><span> <?php echo esc_html( $weight ) . ' ' . get_option( 'woocommerce_weight_unit' ) ?></span></span>
	<?php endif; ?>

	<?php echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="posted_in">' . _n( 'Category:', 'Categories:', count( $product->get_category_ids() ), 'woocommerce' ) . ' ', '</span>' ); ?>

	<?php echo wc_get_product_tag_list( $product->get_id(), ', ', '<span class="tagged_as">' . _n( 'Tag:', 'Tags:', count( $product->get_tag_ids() ), 'woocommerce' ) . ' ', '</span>' ); ?>

	<?php do_action( 'woocommerce_product_meta_end' ); ?>


</div>
