<?php
/**
 * Related Products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/related.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author        WooThemes
 * @package       WooCommerce/Templates
 * @version     3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $product, $woocommerce_loop;

if ( empty( $product ) || !$product->exists() ) {
	return;
}

$related = $product->get_related( $posts_per_page );

if ( sizeof( $related ) == 0 ) {
	return;
}

$args = apply_filters( 'woocommerce_related_products_args', array(
	'post_type'           => 'product',
	'ignore_sticky_posts' => 1,
	'no_found_rows'       => 1,
	'posts_per_page'      => $posts_per_page,
	'orderby'             => $orderby,
	'post__in'            => $related,
	'post__not_in'        => array( $product->id )
) );

$products = new WP_Query( $args );

global $itcode_woocommerce_loop;
$related_product_display_columns = isset( $_GET['columns'] ) ? $_GET['columns'] : '';
if ( !in_array( $related_product_display_columns, array( '3', '4' ) ) ) {
	$related_product_display_columns = get_itcode_options('related_product_display_columns');
}

$itcode_woocommerce_loop['columns'] = $related_product_display_columns;
$itcode_woocommerce_loop['layout']  = 'slider';

if ( $products->have_posts() and get_theme_mod('related_product_enable', 1 ) == 1 ) : ?>

    <!-- start related -->
	<div class="related products">
        <div class="card ">
            <div class="card-header">
                <h4 class="itcode-title"><?php echo esc_html__( 'Related Products', 'itcode' ); ?></h4>
            </div>
            <div class="card-body">
                <?php woocommerce_product_loop_start(); ?>
                <!-- start while-->
                <?php while ( $products->have_posts() ) : $products->the_post(); ?>
                    <?php wc_get_template_part( 'content', 'product' ); ?>
                <?php endwhile; // end of the loop. ?>
                <!-- end while -->
                <?php woocommerce_product_loop_end(); ?>
            </div>
        </div>
	</div>
    <!-- end related -->

<?php endif;

wp_reset_postdata();
